from typing import Any, List, Optional

from dev.coatl.helper.types import AnyStr
from java.awt import Component, Container, Frame, Graphics
from java.util import Locale
from javax.swing.event import AncestorListener
from javax.swing.plaf import DesktopPaneUI
from javax.swing.text import JTextComponent

class DesktopManager:
    def activateFrame(self, f: JInternalFrame) -> None: ...
    def beginDragginFrame(self, f: JComponent) -> None: ...
    def beginResizingFrame(self, f: JComponent, direction: int) -> None: ...
    def closeFrame(self, f: JInternalFrame) -> None: ...
    def deactivateFrame(self, f: JInternalFrame) -> None: ...
    def deiconifyFrame(self, f: JInternalFrame) -> None: ...
    def dragFrame(self, f: JComponent, newX: int, newY: int) -> None: ...
    def endDraggingFrame(self, f: JComponent) -> None: ...
    def endResizing(self, f: JComponent) -> None: ...
    def iconifyFrame(self, f: JInternalFrame) -> None: ...
    def maximizeFrame(self, f: JInternalFrame) -> None: ...
    def minimizeFrame(self, f: JInternalFrame) -> None: ...
    def openFrame(self, f: JInternalFrame) -> None: ...
    def resizeFrame(
        self, f: JComponent, newX: int, newY: int, newWidth: int, newHeight: int
    ) -> None: ...
    def setBoundsForFrame(
        self, f: JComponent, newX: int, newY: int, newWidth: int, newHeight: int
    ) -> None: ...

class Icon:
    def getIconHeight(self) -> int: ...
    def getIconWidth(self) -> int: ...
    def paintIcon(self, c: Component, g: Graphics, x: int, y: int) -> None: ...

class RootPaneContainer:
    def getContentPane(self) -> Container: ...
    def getGlassPane(self) -> Component: ...
    def getLayeredPane(self) -> JLayeredPane: ...
    def getRootPane(self) -> JRootPane: ...
    def setContentPane(self, contentPane: Container) -> None: ...
    def setGlassPane(self, glassPane: Component) -> None: ...
    def setLayeredPane(self, rootPane: JLayeredPane) -> None: ...

class JComponent(Container):
    TOOL_TIP_TEXT_KEY: AnyStr
    UNDEFINED_CONDITION: int
    WHEN_ANCESTOR_OF_FOCUSED_COMPONENT: int
    WHEN_FOCUSED: int
    WHEN_IN_FOCUSED_WINDOW: int
    def __init__(self) -> None: ...
    def addAncestorListener(self, listener: AncestorListener) -> None: ...
    def addNotify(self) -> None: ...
    def createToolTip(self) -> JToolTip: ...
    @staticmethod
    def getDefaultLocale() -> Locale: ...
    @staticmethod
    def isLightweightComponent(c: Component) -> bool: ...
    @staticmethod
    def setDefaultLocale(l: Locale) -> None: ...

class JFrame(Frame):
    def __init__(self, *args: Any) -> None: ...

class JInternalFrame(JComponent):
    def __init__(
        self,
        title: Optional[AnyStr] = ...,
        resizable: Optional[bool] = ...,
        closable: Optional[bool] = ...,
        maximizable: Optional[bool] = ...,
        iconifiable: Optional[bool] = ...,
    ) -> None: ...

class JLabel(JComponent):
    def __init__(self, *args: Any) -> None: ...

class JLayeredPane(JComponent):
    DEFAULT_LAYER: int
    DRAG_LAYER: int
    FRAME_CONTENT_LAYER: int
    LAYER_PROPERTY: str
    MODAL_LAYER: int
    PALETTE_LAYER: int
    POPUP_LAYER: int
    def __init__(self) -> None: ...
    def getComponentCountInLayer(self, layer: int) -> int: ...
    def getLayer(self, c: Component) -> int: ...
    def highestLayer(self) -> int: ...
    def lowestLayer(self) -> int: ...
    def setPosition(self, c: Component, position: int) -> None: ...

class JDesktopPane(JLayeredPane):
    LIVE_DRAG_MODE: int
    OUTLINE_DRAG_MODE: int
    def __init__(self) -> None: ...
    def getAllFrames(self) -> List[JInternalFrame]: ...
    def getAllFramesInLayer(self, layer: int) -> List[JInternalFrame]: ...
    def getDesktopManager(self) -> DesktopManager: ...
    def getDragMode(self) -> int: ...
    def getSelectedFrame(self) -> JInternalFrame: ...
    def getUI(self) -> DesktopPaneUI: ...
    def getUIClassID(self) -> AnyStr: ...
    def updateUI(self) -> None: ...

class JOptionPane(JComponent):
    PLAIN_MESSAGE: int
    ERROR_MESSAGE: int
    INFORMATION_MESSAGE: int
    WARNING_MESSAGE: int
    QUESTION_MESSAGE: int
    DEFAULT_OPTION: int
    YES_NO_OPTION: int
    YES_NO_CANCEL_OPTION: int
    OK_CANCEL_OPTION: int
    CLOSED_OPTION: int
    OK_OPTION: int
    YES_OPTION: int
    NO_OPTION: int
    CANCEL_OPTION: int
    @staticmethod
    def showConfirmDialog(
        parentComponent: Optional[Any],
        message: Any,
        title: Optional[AnyStr] = ...,
        optionType: Optional[int] = ...,
        messageType: Optional[int] = ...,
        icon: Optional[Icon] = ...,
    ) -> int: ...
    @staticmethod
    def showInputDialog(
        parentComponent: Optional[Any],
        message: Any,
        title: Optional[AnyStr] = ...,
        messageType: Optional[int] = ...,
        icon: Optional[Icon] = ...,
        selectionValues: Optional[List[Any]] = ...,
        initialSelectionValue: Optional[Any] = ...,
    ) -> AnyStr: ...
    @staticmethod
    def showMessageDialog(
        parentComponent: Optional[Any],
        message: Any,
        title: Optional[AnyStr] = ...,
        messageType: Optional[int] = ...,
        icon: Optional[Icon] = ...,
    ) -> None: ...
    @staticmethod
    def showOptionDialog(
        parentComponent: Optional[Any],
        message: Any,
        title: Optional[AnyStr] = ...,
        optionType: Optional[int] = ...,
        messageType: Optional[int] = ...,
        icon: Optional[Icon] = ...,
        options: Optional[List[Any]] = ...,
        initialValue: Optional[Any] = ...,
    ) -> int: ...

class JPanel(JComponent):
    def __init__(self, *args: Any) -> None: ...

class JToolTip(JComponent):
    def __init__(self) -> None: ...
    def getComponent(self) -> JComponent: ...
    def getTipText(self) -> AnyStr: ...

class JPopupMenu(JComponent):
    def __init__(self, label: Optional[AnyStr] = ...) -> None: ...

class JRootPane(JComponent):
    def __init__(self) -> None: ...

class JTextField(JTextComponent):
    def __init__(self, *args: Any) -> None: ...

class JPasswordField(JTextField):
    def __init__(self, *args: Any) -> None: ...
    def copy(self) -> None: ...
    def cut(self) -> None: ...
    def echoCharIsSet(self) -> bool: ...
    def getEchoChar(self) -> AnyStr: ...
    def getPassword(self) -> Any: ...
    def getText(self, *args: int) -> unicode: ...
    def getUIClassID(self) -> AnyStr: ...
    def setEchoChar(self, c: AnyStr) -> None: ...
    def updateUI(self) -> None: ...



from typing import Any, Dict, List, Optional, Set, Tuple

from com.inductiveautomation.ignition.common import JsonPath
from com.inductiveautomation.ignition.common.gson import JsonArray, JsonElement
from dev.coatl.helper.types import AnyStr
from java.io import InputStream
from java.lang import Enum, Object
from java.util.regex import Pattern

class JsonValidator:
    AT_ROOT: AnyStr
    def validate(self, *args: Any) -> Set[ValidationMessage]: ...

class BaseJsonValidator(Object, JsonValidator):
    def __init__(self, *args: Any) -> None: ...
    def asInt(self, element: JsonElement) -> int: ...
    def validate(self, *args: Any) -> Set[ValidationMessage]: ...

class ItemsValidator(BaseJsonValidator):
    PROPERTY: AnyStr
    def __init__(self, *args: Any) -> None: ...
    def deriveDefaultArray(self, includeExample: Optional[bool] = ...) -> JsonArray: ...
    def findSchemaForIndex(self, index: int) -> Optional[JsonSchema]: ...
    def getDefaultItem(self) -> Optional[JsonElement]: ...
    def getSchemas(self) -> List[JsonSchema]: ...
    def isBoundedSchema(self) -> Set[ValidationMessage]: ...

class JsonSchema(BaseJsonValidator):
    IGNITION_SCHEMA_PATTERN: Pattern
    IGNITION_SCHEMA_URN: AnyStr
    def __init__(self, *args: Any) -> None: ...
    def acceptsType(self, type: JsonType) -> bool: ...
    def findAncestor(self) -> JsonSchema: ...
    def findAncestorMatchingPath(
        self, matchingPath: AnyStr
    ) -> Optional[JsonSchema]: ...
    def findSchemaForPath(self, path: JsonPath) -> Optional[JsonSchema]: ...
    def getChildDefaultValue(self, type: JsonType) -> Optional[JsonElement]: ...
    def getDeclaredProperties(self) -> List[AnyStr]: ...
    def getDefaultValue(self, includeExamples: Optional[bool] = ...) -> JsonElement: ...
    def getDescription(self) -> AnyStr: ...
    def getDynamicSuggestionPath(self) -> AnyStr: ...
    def getEnumChoices(self) -> Dict[AnyStr, JsonElement]: ...
    def getExamples(self) -> List[JsonElement]: ...
    def getExampleValue(self) -> Optional[JsonElement]: ...
    def getExtension(self, key: AnyStr) -> Optional[JsonElement]: ...
    def getFormat(self) -> AnyStr: ...
    def getItemsValidator(self) -> ItemsValidator: ...
    def getRefSchemaNode(self, ref: Optional[AnyStr] = ...) -> JsonElement: ...
    def getSchemasForItems(self) -> List[JsonSchema]: ...
    def getSchemasForProperties(self) -> Dict[AnyStr, JsonSchema]: ...
    def getSuggestions(self) -> Dict[AnyStr, JsonElement]: ...
    def getTitle(self) -> AnyStr: ...
    def getTypeValidator(self) -> TypeValidator: ...
    def getVisibleWhenCondition(self) -> Optional[Tuple[AnyStr, List[JsonElement]]]: ...
    def hasChildren(self) -> bool: ...
    def isDeprecated(self) -> bool: ...
    def isType(self, type: JsonType) -> bool: ...
    @staticmethod
    def parse(stream: InputStream) -> JsonSchema: ...

class JsonType(Enum):
    OBJECT: str
    ARRAY: str
    STRING: str
    NUMBER: str
    INTEGER: str
    BOOLEAN: str
    NULL: str
    DATASET: str
    DATE: str
    UNKNOWN: str
    @staticmethod
    def typeOf(element: JsonElement) -> JsonType: ...
    @staticmethod
    def values() -> List[JsonType]: ...

class ValidationMessage(Object):
    def getCode(self) -> AnyStr: ...
    def getMessage(self) -> AnyStr: ...
    def getPath(self) -> AnyStr: ...
    def getType(self) -> AnyStr: ...
    def setArguments(self, *args: AnyStr) -> None: ...
    def setType(self, type: AnyStr) -> None: ...

    class Builder(Object):
        def arguments(self, *args: AnyStr) -> ValidationMessage.Builder: ...
        def build(self) -> ValidationMessage: ...
        def code(self, code: AnyStr) -> ValidationMessage.Builder: ...
        def format(self, format: AnyStr) -> ValidationMessage.Builder: ...
        def path(self, path: AnyStr) -> ValidationMessage.Builder: ...
        def type(self, type: AnyStr) -> ValidationMessage.Builder: ...

class TypeValidator(BaseJsonValidator):
    def __init__(self, *args: Any) -> None: ...
    def getAcceptedTypes(self) -> Set[JsonType]: ...



from typing import Any, Dict, List, Optional, Union

from com.inductiveautomation.ignition.common.script.adapters import PyJsonObjectAdapter
from dev.coatl.helper.types import AnyStr

def alterDock(
    dockId: AnyStr,
    config: Optional[Dict[AnyStr, Any]] = ...,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
) -> None: ...
def alterLogging(
    remoteLoggingEnabled: bool = ...,
    level: AnyStr = ...,
    remoteLoggingLevel: AnyStr = ...,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
) -> None: ...
def authenticationChallenge(
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
    idp: AnyStr = ...,
    forceAuth: bool = ...,
    timeout: int = ...,
    payload: Optional[Dict[AnyStr, Any]] = ...,
    framing: AnyStr = ...,
) -> None: ...
def closeDock(id: AnyStr, sessionId: AnyStr = ..., pageId: AnyStr = ...) -> None: ...
def closePage(
    message: Optional[AnyStr] = ..., sessionId: AnyStr = ..., pageId: AnyStr = ...
) -> None: ...
def closePopup(id: AnyStr, sessionId: AnyStr = ..., pageId: AnyStr = ...) -> None: ...
def closeSession(message: Optional[AnyStr] = ..., sessionId: AnyStr = ...) -> None: ...
def download(
    filename: AnyStr,
    data: Any,
    contentType: Optional[AnyStr] = ...,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
) -> None: ...
def getProjectInfo() -> Dict[AnyStr, Any]: ...
def getSessionInfo(
    usernameFilter: Optional[AnyStr] = ..., projectFilter: Optional[AnyStr] = ...
) -> List[PyJsonObjectAdapter]: ...
def isAuthorized(
    isAllOf: bool, securityLevels: List[AnyStr], sessionId: AnyStr = ...
) -> bool: ...
def login(
    sessionId: AnyStr = ..., pageId: AnyStr = ..., forceAuth: bool = ...
) -> None: ...
def logout(
    sessionId: AnyStr = ..., pageId: AnyStr = ..., message: AnyStr = ...
) -> None: ...
def navigate(
    page: AnyStr,
    url: Optional[AnyStr] = ...,
    view: Optional[AnyStr] = ...,
    params: Optional[Dict[AnyStr, AnyStr]] = ...,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
    newTab: bool = ...,
) -> None: ...
def navigateBack(sessionId: AnyStr = ..., pageId: AnyStr = ...) -> None: ...
def navigateForward(sessionId: AnyStr = ..., pageId: AnyStr = ...) -> None: ...
def openDock(
    id: AnyStr,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
    params: Optional[Dict[AnyStr, AnyStr]] = ...,
) -> None: ...
def openPopup(
    id: AnyStr,
    view: AnyStr,
    params: Optional[Dict[AnyStr, Any]] = ...,
    title: AnyStr = ...,
    position: Optional[Dict[AnyStr, Union[int, AnyStr]]] = ...,
    showCloseIcon: bool = ...,
    draggable: bool = ...,
    resizable: bool = ...,
    modal: bool = ...,
    overlayDismiss: bool = ...,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
    viewPortBound: bool = ...,
) -> None: ...
def print(
    message: AnyStr,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
    destination: AnyStr = ...,
) -> None: ...
def refresh(sessionId: AnyStr = ..., pageId: AnyStr = ...) -> None: ...
def sendMessage(
    messageType: AnyStr,
    payload: Dict[AnyStr, AnyStr],
    scope: AnyStr = ...,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
) -> None: ...
def setTheme(name: AnyStr, sessionId: AnyStr = ..., pageId: AnyStr = ...) -> None: ...
def toggleDock(
    id: AnyStr,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
    params: Optional[Dict[AnyStr, AnyStr]] = ...,
) -> None: ...
def togglePopup(
    id: AnyStr,
    view: AnyStr,
    params: Optional[Dict[AnyStr, Any]],
    title: AnyStr = ...,
    position: Optional[Dict[AnyStr, Union[int, AnyStr]]] = ...,
    showCloseIcon: bool = ...,
    draggable: bool = ...,
    resizable: bool = ...,
    modal: bool = ...,
    overlayDismiss: bool = ...,
    sessionId: AnyStr = ...,
    pageId: AnyStr = ...,
    viewPortBound: bool = ...,
) -> None: ...
def vibrateDevice(duration: int, sessionId: AnyStr = ...) -> None: ...



from typing import Any, Optional

from dev.coatl.helper.types import AnyStr
from java.lang import Object, Throwable
from java.util import Enumeration
from org.apache.log4j.spi import ErrorHandler, Filter, LoggerRepository, LoggingEvent

class Appender:
    def addFilter(self, newFilter: Filter) -> None: ...
    def clearFilters(self) -> None: ...
    def close(self) -> None: ...
    def doAppend(self, event: LoggingEvent) -> None: ...
    def getErrorHandler(self) -> ErrorHandler: ...
    def getFilter(self) -> Filter: ...
    def getLayout(self) -> Layout: ...
    def getName(self) -> AnyStr: ...
    def requiresLayout(self) -> bool: ...
    def setErrorHandler(self, errorHandler: ErrorHandler) -> None: ...
    def setLayout(self, layout: Layout) -> None: ...
    def setName(self, name: AnyStr) -> None: ...

class Category(Object):
    def addApender(self, newAppender: Appender) -> None: ...
    def assertLog(self, assertion: bool, msg: AnyStr) -> None: ...
    def callAppenders(self, event: LoggingEvent) -> None: ...
    def debug(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def error(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def fatal(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def getAdditivity(self) -> bool: ...
    def getAllAppenders(self) -> Enumeration: ...
    def getAppender(self, name: AnyStr) -> Appender: ...
    def getLevel(self) -> Level: ...
    def getLoggerRepository(self) -> LoggerRepository: ...
    def info(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...
    def warn(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...

class Layout(Object):
    def __init__(self) -> None: ...
    def format(self, event: LoggingEvent) -> AnyStr: ...
    def getContentType(self) -> AnyStr: ...
    def getFooter(self) -> AnyStr: ...
    def getHeader(self) -> AnyStr: ...
    def ignoresThrowable(self) -> bool: ...

class Priority(Object):
    def getSyslogEquivalent(self) -> int: ...
    def isGreaterOrEqual(self, r: Priority) -> bool: ...
    def toInt(self) -> int: ...

class Level(Priority):
    @staticmethod
    def toLevel(*args: Any) -> Level: ...

class Logger(Category):
    @staticmethod
    def getLogger(*args: Any) -> Logger: ...
    def isTraceEnabled(self) -> bool: ...
    def trace(self, message: AnyStr, t: Optional[Throwable] = ...) -> None: ...



# flake8: noqa
from org.bson.types import Binary as Binary
from org.bson.types import BSONTimestamp as Timestamp
from org.bson.types import Code as Code
from org.bson.types import CodeWithScope as CodeWithScope
from org.bson.types import CodeWScope as CodeWScope
from org.bson.types import Decimal128 as Decimal128
from org.bson.types import MaxKey as MaxKey
from org.bson.types import MinKey as MinKey
from org.bson.types import ObjectId as ObjectId
from org.bson.types import Symbol as Symbol



from java.lang import Exception as JavaException
from java.lang import Object
from org.python.core import PyFunction

class RequestWatcher:
    def block(self) -> bool: ...
    def compose(self, *args: RequestWatcher) -> RequestWatcher: ...

class Request(RequestWatcher):
    def block(self) -> bool: ...
    def cancel(self) -> None: ...
    def compose(self, *args: RequestWatcher) -> RequestWatcher: ...
    def get(self) -> Object: ...
    def getError(self) -> JavaException: ...
    def onError(self, func: PyFunction) -> None: ...
    def onSuccess(self, func: PyFunction) -> None: ...



from typing import Any, List, Union

from com.inductiveautomation.factorypmi.application.components import BasicContainer
from com.inductiveautomation.ignition.client.model import ClientContext, DesktopListener
from com.inductiveautomation.ignition.common.project.resource import ResourcePath
from com.inductiveautomation.ignition.common.script import ScriptManager
from dev.coatl.helper.types import AnyStr
from java.util import TimeZone
from javax.swing import JDesktopPane, JInternalFrame

class VisionDesktop(JDesktopPane):
    PRIMARY_DESKTOP_HANDLE: str
    def __init__(self, clientContext: ClientContext, handle: AnyStr = ...) -> None: ...
    def addDesktopListener(self, arg: DesktopListener) -> None: ...
    def getAdapterContext(self) -> Any: ...
    def getHandle(self) -> AnyStr: ...
    def getOpenedWindows(self) -> List[FPMIWindow]: ...
    def getPath(self, window: FPMIWindow) -> AnyStr: ...
    def getScriptManager(self) -> ScriptManager: ...
    def getWindow(self, arg: Union[AnyStr, ResourcePath]) -> FPMIWindow: ...

class FPMIApp(VisionDesktop):
    TIMEZONE_CLIENT: str
    TIMEZONE_GATEWAY: str
    def getDefaultTimeZone(self) -> AnyStr: ...
    def getLastActivity(self) -> long: ...
    def shutdownDesigner(self) -> None: ...
    def startupDesigner(self, gatewayTimeZone: TimeZone) -> None: ...

class FPMIWindow(JInternalFrame):
    CACHE_ALWAYS: int
    CACHE_AUTO: int
    CACHE_NEVER: int
    DOCK_EAST: int
    DOCK_FLOAT: int
    DOCK_NORTH: int
    DOCK_SOUTH: int
    DOCK_WEST: int
    PARENT_WINDOW_NAME: str
    SHOW_ALWAYS: int
    SHOW_NEVER: int
    SHOW_MAXIMIZED: int
    name: AnyStr
    def __init__(self, name: AnyStr) -> None: ...
    def getPath(self) -> AnyStr: ...
    def getRootContainer(self) -> BasicContainer: ...



import __builtin__ as builtins
from typing import Any, List, Optional, Union

from dev.coatl.helper.types import AnyStr
from java.lang.reflect import Type
from java.nio import CharBuffer

class Object:
    def __init__(self) -> None: ...
    def __cmp__(self, other: Object) -> bool: ...
    def __ge__(self, other: Object) -> bool: ...
    def __gt__(self, other: Object) -> bool: ...
    def __lt__(self, other: Object) -> bool: ...
    def equals(self, obj: Object) -> bool: ...
    def getClass(self) -> Class: ...
    def hashCode(self) -> int: ...
    def notify(self) -> None: ...
    def notifyAll(self) -> None: ...
    def toString(self) -> AnyStr: ...
    def wait(self, timeoutMillis: long = ..., nanos: int = ...) -> None: ...

class Appendable:
    def append(
        self, c_csq: Union[CharSequence, str], start: int = ..., end: int = ...
    ) -> Appendable: ...

class AutoCloseable:
    def close(self) -> None: ...

class CharSequence:
    def charAt(self, index: int) -> str: ...
    def chars(self) -> None: ...
    def codePoints(self) -> None: ...
    @staticmethod
    def compare(cs1: CharSequence, cs2: CharSequence) -> int: ...
    def length(self) -> int: ...
    def subSequence(self, start: int, end: int) -> CharSequence: ...
    def toString(self) -> AnyStr: ...

class Comparable:
    def compareTo(self, o: Any) -> int: ...

class Readable:
    def read(self, cb: CharBuffer) -> int: ...

class Runnable:
    def run(self) -> None: ...

class Class(Object, Type):
    def asSubClass(self, clazz: Class) -> Any: ...
    def cast(self, obj: Object) -> Any: ...
    def getTypeName(self) -> AnyStr: ...

class Enum(Object):
    def compareTo(self, o: Enum) -> int: ...
    def getDeclaringClass(self) -> Class: ...
    def name(self) -> AnyStr: ...
    def ordinal(self) -> int: ...
    @staticmethod
    def valueOf(enumType: Class, name: AnyStr) -> Enum: ...

class Number(Object):
    def byteValue(self) -> int: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def intValue(self) -> int: ...
    def longValue(self) -> long: ...
    def shortValue(self) -> int: ...

class StackTraceElement(Object):
    def __init__(self, *args: Any) -> None: ...
    def getClassLoaderName(self) -> str: ...
    def getClassName(self) -> str: ...
    def getFileName(self) -> str: ...
    def getLineNumber(self) -> int: ...
    def getMethodName(self) -> str: ...
    def getModuleName(self) -> str: ...
    def getModuleVersion(self) -> str: ...
    def isNativeMethod(self) -> bool: ...

class String(unicode):
    def __new__(cls, *args: Any) -> Any: ...
    def __init__(self, *args: Any) -> None: ...
    def charAt(self, index: int) -> unicode: ...
    def chars(self) -> None: ...
    def codePointAt(self, index: int) -> int: ...
    def codePointBefore(self, index: int) -> int: ...
    def codePointCount(self, beginIndex: int, endIndex: int) -> int: ...
    def codePoints(self) -> None: ...
    @staticmethod
    def compare(cs1: CharSequence, cs2: CharSequence) -> int: ...
    def compareTo(self, anotherString: String) -> int: ...
    def compareToIgnoreCase(self, arg: String) -> int: ...
    def concat(self, arg: String) -> String: ...
    def contains(self, arg: String) -> bool: ...
    def contentEquals(self, arg: Union[CharSequence, StringBuffer]) -> bool: ...
    @staticmethod
    def copyValueOf(*args: Any) -> String: ...
    def endsWith(self, suffix: String) -> bool: ...
    def equals(self, anObject: Object) -> bool: ...
    def equalsIgnoreCase(self, anotherString: String) -> bool: ...
    def getBytes(self, *args: Any) -> Optional[object]: ...
    def getChars(
        self, srcBegin: int, srcEnd: int, dst: object, dstBegin: int
    ) -> None: ...
    def getClass(self) -> Class: ...
    def hashCode(self) -> int: ...
    def indexOf(
        self, arg: Union[int, String], fromIndex: Optional[int] = ...
    ) -> int: ...
    def intern(self) -> String: ...
    def isBlank(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def lastIndexOf(
        self, arg: Union[int, String], fromIndex: Optional[int] = ...
    ) -> int: ...
    def length(self) -> int: ...
    def lines(self) -> None: ...
    def matches(self, regex: String) -> bool: ...
    def notify(self) -> None: ...
    def notifyAll(self) -> None: ...
    def offsetByCodePoints(self, index: int, codePointOffset: int) -> int: ...
    def regionMatches(self, *args: Any) -> bool: ...
    def repeat(self, count: int) -> String: ...
    def replaceAll(self, regex: String, replacement: String) -> String: ...
    def replaceFirst(self, regex: String, replacement: String) -> String: ...
    def startsWith(self, prefix: String, offset: int = ...) -> bool: ...
    def stripLeading(self) -> String: ...
    def stripTrailing(self) -> String: ...
    def subSequence(self, start: int, end: int) -> CharSequence: ...
    def substring(self, beginIndex: int, endIndex: Optional[int] = ...) -> String: ...
    def toCharArray(self) -> object: ...
    def toLowerCase(self, locale: Optional[Any] = ...) -> String: ...
    def toString(self) -> unicode: ...
    def toUpperCase(self) -> String: ...
    @staticmethod
    def valueOf(*args: Any) -> String: ...
    def wait(self, timeoutMillis: long = ..., nanos: int = ...) -> None: ...

class StringBuffer(Object, CharSequence):
    def __init__(self, *args: Any) -> None: ...
    def append(self, *args: Any) -> StringBuffer: ...
    def appendCodePoint(self, codePoint: int) -> StringBuffer: ...
    def capacity(self) -> int: ...
    def charAt(self, index: int) -> str: ...
    def codePointAt(self, index: int) -> int: ...
    def codePointBefore(self, index: int) -> int: ...
    def codePointCount(self, beginIndex: int, endIndex: int) -> int: ...
    def compareTo(self, another: StringBuffer) -> int: ...
    def delete(self, start: int, end: int) -> StringBuffer: ...
    def deleteCharAt(self, index: int) -> StringBuffer: ...
    def ensureCapacity(self, minimumCapacity: int) -> None: ...
    def getChars(self, srcBegin: int, srcEnd: int, dst: str, dstBegin: int) -> None: ...
    def indexOf(self, string: str, fromIndex: int = ...) -> int: ...
    def insert(self, *args: Any) -> StringBuffer: ...
    def lastIndexOf(self, string: str, fromIndex: int = ...) -> int: ...
    def length(self) -> int: ...
    def offsetByCodePoints(self, index: int, codePointOffset: int) -> int: ...
    def replace(self, start: int, end: int, string: str) -> StringBuffer: ...
    def reverse(self) -> StringBuffer: ...
    def setCharAt(self, index: int, ch: str) -> None: ...
    def setLength(self, newLength: int) -> None: ...
    def subSequence(self, start: int, end: int) -> CharSequence: ...
    def substring(self, start: int, end: int = ...) -> str: ...
    def trimToSize(self) -> None: ...

class StringBuilder(Object, CharSequence):
    def __init__(self, *args: Any) -> None: ...
    def append(self, *args: Any) -> StringBuilder: ...
    def capacity(self) -> int: ...
    def charAt(self, index: int) -> str: ...
    def codePointAt(self, index: int) -> int: ...
    def codePointBefore(self, index: int) -> int: ...
    def codePointCount(self, beginIndex: int, endIndex: int) -> int: ...
    def compareTo(self, another: StringBuilder) -> int: ...
    def delete(self, start: int, end: int) -> StringBuilder: ...
    def deleteCharAt(self, index: int) -> StringBuilder: ...
    def ensureCapacity(self, minimumCapacity: int) -> None: ...
    def getChars(self, srcBegin: int, srcEnd: int, dst: str, dstBegin: int) -> None: ...
    def indexOf(self, str_: AnyStr, fromIndex: int = ...) -> int: ...
    def insert(self, *args: Any) -> StringBuilder: ...
    def lastIndexOf(self, str_: AnyStr, fromIndex: int = ...) -> int: ...
    def length(self) -> int: ...
    def offsetByCodePoints(self, index: int, codePointOffset: int) -> int: ...
    def replace(self, start: int, end: int, str_: int) -> StringBuilder: ...
    def reverse(self) -> StringBuilder: ...
    def setCharAt(self, index: int, ch: str) -> None: ...
    def setLength(self, newLength: int) -> None: ...
    def subSequence(self, start: int, end: int) -> CharSequence: ...
    def substring(self, start: int, end: int = ...) -> AnyStr: ...
    def trimToSize(self) -> None: ...

class Throwable(Object, builtins.Exception):
    def __init__(
        self, message: Optional[str] = ..., cause: Optional[Throwable] = ...
    ) -> None: ...
    @property
    def cause(self) -> Throwable: ...
    def addSuppressed(self, exception: Throwable) -> None: ...
    def fillInStackTrace(self) -> Throwable: ...
    def getCause(self) -> Throwable: ...
    def getLocalizedMessage(self) -> str: ...
    def getMessage(self) -> str: ...
    def getStackTrace(self) -> List[StackTraceElement]: ...
    def getSuppressed(self) -> List[Throwable]: ...
    def initCause(self, cause: Optional[Throwable] = ...) -> None: ...
    @property
    def message(self) -> str: ...
    def printStackTrace(self, *args: Any) -> None: ...
    def setStackTrace(self, stackTrace: List[StackTraceElement]) -> None: ...
    def toString(self) -> AnyStr: ...

class Exception(Throwable):
    def __init__(
        self, message: Optional[str] = ..., cause: Optional[Throwable] = ...
    ) -> None: ...

class RuntimeException(Exception):
    def __init__(
        self, message: Optional[str] = ..., cause: Optional[Throwable] = ...
    ) -> None: ...

class IllegalArgumentException(RuntimeException):
    def __init__(
        self, message: Optional[str] = ..., cause: Optional[Throwable] = ...
    ) -> None: ...

class NullPointerException(RuntimeException):
    def __init__(
        self, message: Optional[str] = ..., cause: Optional[Throwable] = ...
    ) -> None: ...

class Thread(Object):
    @staticmethod
    def sleep(millis: long) -> None: ...



from enum import Enum

class ObjectType(Enum):
    analogInput: int
    analogOutput: int
    analogValue: int
    binaryInput: int
    binaryOutput: int
    binaryValue: int
    calendar: int
    command: int
    device: int
    eventEnrollment: int
    file: int
    group: int
    loop: int
    multiStateInput: int
    multiStateOutput: int
    notificationClass: int
    program: int
    schedule: int
    averaging: int
    multiStateValue: int
    trendLog: int
    lifeSafetyPoint: int
    lifeSafetyZone: int
    accumulator: int
    pulseConverter: int
    eventLog: int
    globalGroup: int
    trendLogMultiple: int
    loadControl: int
    structuredView: int
    accessDoor: int
    timer: int
    accessCredential: int
    accessPoint: int
    accessRights: int
    accessUser: int
    accessZone: int
    credentialDataInput: int
    networkSecurity: int
    bitstringValue: int
    characterstringValue: int
    datePatternValue: int
    dateValue: int
    datetimePatternValue: int
    datetimeValue: int
    integerValue: int
    largeAnalogValue: int
    octetstringValue: int
    positiveIntegerValue: int
    timePatternValue: int
    timeValue: int
    notificationForwarder: int
    alertEnrollment: int
    channel: int
    lightingOutput: int
    binaryLightingOutput: int
    networkPort: int
    elevatorGroup: int
    escalator: int
    lift: int

class PropertyIdentifier(Enum):
    ackedTransitions: int
    ackRequired: int
    action: int
    actionText: int
    activeText: int
    activeVtSessions: int
    alarmValue: int
    alarmValues: int
    all: int
    allWritesSuccessful: int
    apduSegmentTimeout: int
    apduTimeout: int
    applicationSoftwareVersion: int
    archive: int
    bias: int
    changeOfStateCount: int
    changeOfStateTime: int
    notificationClass: int
    controlledVariableReference: int
    controlledVariableUnits: int
    controlledVariableValue: int
    covIncrement: int
    dateList: int
    daylightSavingsStatus: int
    deadband: int
    derivativeConstant: int
    derivativeConstantUnits: int
    description: int
    descriptionOfHalt: int
    deviceAddressBinding: int
    deviceType: int
    effectivePeriod: int
    elapsedActiveTime: int
    errorLimit: int
    eventEnable: int
    eventState: int
    eventType: int
    exceptionSchedule: int
    faultValues: int
    feedbackValue: int
    fileAccessMethod: int
    fileSize: int
    fileType: int
    firmwareRevision: int
    highLimit: int
    inactiveText: int
    inProcess: int
    instanceOf: int
    integralConstant: int
    integralConstantUnits: int
    limitEnable: int
    listOfGroupMembers: int
    listOfObjectPropertyReferences: int
    localDate: int
    localTime: int
    location: int
    lowLimit: int
    manipulatedVariableReference: int
    maximumOutput: int
    maxApduLengthAccepted: int
    maxInfoFrames: int
    maxMaster: int
    maxPresValue: int
    minimumOffTime: int
    minimumOnTime: int
    minimumOutput: int
    minPresValue: int
    modelName: int
    modificationDate: int
    notifyType: int
    numberOfApduRetries: int
    numberOfStates: int
    objectIdentifier: int
    objectList: int
    objectName: int
    objectPropertyReference: int
    objectType: int
    optional: int
    outOfService: int
    outputUnits: int
    eventParameters: int
    polarity: int
    presentValue: int
    priority: int
    priorityArray: int
    priorityForWriting: int
    processIdentifier: int
    programChange: int
    programLocation: int
    programState: int
    proportionalConstant: int
    proportionalConstantUnits: int
    protocolObjectTypesSupported: int
    protocolServicesSupported: int
    protocolVersion: int
    readOnly: int
    reasonForHalt: int
    recipientList: int
    reliability: int
    relinquishDefault: int
    required: int
    resolution: int
    segmentationSupported: int
    setpoint: int
    setpointReference: int
    stateText: int
    statusFlags: int
    systemStatus: int
    timeDelay: int
    timeOfActiveTimeReset: int
    timeOfStateCountReset: int
    timeSynchronizationRecipients: int
    units: int
    updateInterval: int
    utcOffset: int
    vendorIdentifier: int
    vendorName: int
    vtClassesSupported: int
    weeklySchedule: int
    attemptedSamples: int
    averageValue: int
    bufferSize: int
    clientCovIncrement: int
    covResubscriptionInterval: int
    eventTimeStamps: int
    logBuffer: int
    logDeviceObjectProperty: int
    enable: int
    logInterval: int
    maximumValue: int
    minimumValue: int
    notificationThreshold: int
    protocolRevision: int
    recordsSinceNotification: int
    recordCount: int
    startTime: int
    stopTime: int
    stopWhenFull: int
    totalRecordCount: int
    validSamples: int
    windowInterval: int
    windowSamples: int
    maximumValueTimestamp: int
    minimumValueTimestamp: int
    varianceValue: int
    activeCovSubscriptions: int
    backupFailureTimeout: int
    configurationFiles: int
    databaseRevision: int
    directReading: int
    lastRestoreTime: int
    maintenanceRequired: int
    memberOf: int
    mode: int
    operationExpected: int
    setting: int
    silenced: int
    trackingValue: int
    zoneMembers: int
    lifeSafetyAlarmValues: int
    maxSegmentsAccepted: int
    profileName: int
    autoSlaveDiscovery: int
    manualSlaveAddressBinding: int
    slaveAddressBinding: int
    slaveProxyEnable: int
    lastNotifyRecord: int
    scheduleDefault: int
    acceptedModes: int
    adjustValue: int
    count: int
    countBeforeChange: int
    countChangeTime: int
    covPeriod: int
    inputReference: int
    limitMonitoringInterval: int
    loggingObject: int
    loggingRecord: int
    prescale: int
    pulseRate: int
    scale: int
    scaleFactor: int
    updateTime: int
    valueBeforeChange: int
    valueSet: int
    valueChangeTime: int
    alignIntervals: int
    intervalOffset: int
    lastRestartReason: int
    loggingType: int
    restartNotificationRecipients: int
    timeOfDeviceRestart: int
    timeSynchronizationInterval: int
    trigger: int
    utcTimeSynchronizationRecipients: int
    nodeSubtype: int
    nodeType: int
    structuredObjectList: int
    subordinateAnnotations: int
    subordinateList: int
    actualShedLevel: int
    dutyWindow: int
    expectedShedLevel: int
    fullDutyBaseline: int
    requestedShedLevel: int
    shedDuration: int
    shedLevelDescriptions: int
    shedLevels: int
    stateDescription: int
    doorAlarmState: int
    doorExtendedPulseTime: int
    doorMembers: int
    doorOpenTooLongTime: int
    doorPulseTime: int
    doorStatus: int
    doorUnlockDelayTime: int
    lockStatus: int
    maskedAlarmValues: int
    securedStatus: int
    absenteeLimit: int
    accessAlarmEvents: int
    accessDoors: int
    accessEvent: int
    accessEventAuthenticationFactor: int
    accessEventCredential: int
    accessEventTime: int
    accessTransactionEvents: int
    accompaniment: int
    accompanimentTime: int
    activationTime: int
    activeAuthenticationPolicy: int
    assignedAccessRights: int
    authenticationFactors: int
    authenticationPolicyList: int
    authenticationPolicyNames: int
    authenticationStatus: int
    authorizationMode: int
    belongsTo: int
    credentialDisable: int
    credentialStatus: int
    credentials: int
    credentialsInZone: int
    daysRemaining: int
    entryPoints: int
    exitPoints: int
    expirationTime: int
    extendedTimeEnable: int
    failedAttemptEvents: int
    failedAttempts: int
    failedAttemptsTime: int
    lastAccessEvent: int
    lastAccessPoint: int
    lastCredentialAdded: int
    lastCredentialAddedTime: int
    lastCredentialRemoved: int
    lastCredentialRemovedTime: int
    lastUseTime: int
    lockout: int
    lockoutRelinquishTime: int
    maxFailedAttempts: int
    members: int
    musterPoint: int
    negativeAccessRules: int
    numberOfAuthenticationPolicies: int
    occupancyCount: int
    occupancyCountAdjust: int
    occupancyCountEnable: int
    occupancyLowerLimit: int
    occupancyLowerLimitEnforced: int
    occupancyState: int
    occupancyUpperLimit: int
    occupancyUpperLimitEnforced: int
    passbackMode: int
    passbackTimeout: int
    positiveAccessRules: int
    reasonForDisable: int
    supportedFormats: int
    supportedFormatClasses: int
    threatAuthority: int
    threatLevel: int
    traceFlag: int
    transactionNotificationClass: int
    userExternalIdentifier: int
    userInformationReference: int
    userName: int
    userType: int
    usesRemaining: int
    zoneFrom: int
    zoneTo: int
    accessEventTag: int
    globalIdentifier: int
    verificationTime: int
    baseDeviceSecurityPolicy: int
    distributionKeyRevision: int
    doNotHide: int
    keySets: int
    lastKeyServer: int
    networkAccessSecurityPolicies: int
    packetReorderTime: int
    securityPduTimeout: int
    securityTimeWindow: int
    supportedSecurityAlgorithms: int
    updateKeySetTimeout: int
    backupAndRestoreState: int
    backupPreparationTime: int
    restoreCompletionTime: int
    restorePreparationTime: int
    bitMask: int
    bitText: int
    isUtc: int
    groupMembers: int
    groupMemberNames: int
    memberStatusFlags: int
    requestedUpdateInterval: int
    covuPeriod: int
    covuRecipients: int
    eventMessageTexts: int
    eventMessageTextsConfig: int
    eventDetectionEnable: int
    eventAlgorithmInhibit: int
    eventAlgorithmInhibitRef: int
    timeDelayNormal: int
    reliabilityEvaluationInhibit: int
    faultParameters: int
    faultType: int
    localForwardingOnly: int
    processIdentifierFilter: int
    subscribedRecipients: int
    portFilter: int
    authorizationExemptions: int
    allowGroupDelayInhibit: int
    channelNumber: int
    controlGroups: int
    executionDelay: int
    lastPriority: int
    writeStatus: int
    propertyList: int
    serialNumber: int
    blinkWarnEnable: int
    defaultFadeTime: int
    defaultRampRate: int
    defaultStepIncrement: int
    egressTime: int
    inProgress: int
    instantaneousPower: int
    lightingCommand: int
    lightingCommandDefaultPriority: int
    maxActualValue: int
    minActualValue: int
    power: int
    transition: int
    egressActive: int
    interfaceValue: int
    faultHighLimit: int
    faultLowLimit: int
    lowDiffLimit: int
    strikeCount: int
    timeOfStrikeCountReset: int
    defaultTimeout: int
    initialTimeout: int
    lastStateChange: int
    stateChangeValues: int
    timerRunning: int
    timerState: int
    apduLength: int
    ipAddress: int
    ipDefaultGateway: int
    ipDhcpEnable: int
    ipDhcpLeaseTime: int
    ipDhcpLeaseTimeRemaining: int
    ipDhcpServer: int
    ipDnsServer: int
    bacnetIpGlobalAddress: int
    bacnetIpMode: int
    bacnetIpMulticastAddress: int
    bacnetIpNatTraversal: int
    ipSubnetMask: int
    bacnetIpUdpPort: int
    bbmdAcceptFdRegistrations: int
    bbmdBroadcastDistributionTable: int
    bbmdForeignDeviceTable: int
    changesPending: int
    command: int
    fdBbmdAddress: int
    fdSubscriptionLifetime: int
    linkSpeed: int
    linkSpeeds: int
    linkSpeedAutonegotiate: int
    macAddress: int
    networkInterfaceName: int
    networkNumber: int
    networkNumberQuality: int
    networkType: int
    routingTable: int
    virtualMacAddressTable: int
    commandTimeArray: int
    currentCommandPriority: int
    lastCommandTime: int
    valueSource: int
    valueSourceArray: int
    bacnetIpv6Mode: int
    ipv6Address: int
    ipv6PrefixLength: int
    bacnetIpv6UdpPort: int
    ipv6DefaultGateway: int
    bacnetIpv6MulticastAddress: int
    ipv6DnsServer: int
    ipv6AutoAddressingEnable: int
    ipv6DhcpLeaseTime: int
    ipv6DhcpLeaseTimeRemaining: int
    ipv6DhcpServer: int
    ipv6ZoneIndex: int
    assignedLandingCalls: int
    carAssignedDirection: int
    carDoorCommand: int
    carDoorStatus: int
    carDoorText: int
    carDoorZone: int
    carDriveStatus: int
    carLoad: int
    carLoadUnits: int
    carMode: int
    carMovingDirection: int
    carPosition: int
    elevatorGroup: int
    energyMeter: int
    energyMeterRef: int
    escalatorMode: int
    faultSignals: int
    floorText: int
    groupId: int
    groupMode: int
    higherDeck: int
    installationId: int
    landingCalls: int
    landingCallControl: int
    landingDoorStatus: int
    lowerDeck: int
    machineRoomId: int
    makingCarCall: int
    nextStoppingFloor: int
    operationDirection: int
    passengerAlarm: int
    powerMode: int
    registeredCarCall: int
    activeCovMultipleSubscriptions: int
    protocolLevel: int
    referencePort: int
    deployedProfileLocation: int
    profileLocation: int
    tags: int
    subordinateNodeTypes: int
    subordinateTags: int
    subordinateRelationships: int
    defaultSubordinateRelationship: int
    represents: int



from typing import Dict, Optional, Set, Union

from dev.coatl.helper.types import AnyStr
from java.lang import Object
from java.nio import ByteBuffer, CharBuffer
from java.util import Locale

class Charset(Object):
    def aliases(self) -> Set[AnyStr]: ...
    @staticmethod
    def availableCharsets() -> Dict[AnyStr, Charset]: ...
    def canEncode(self) -> bool: ...
    def compareTo(self, that: Charset) -> int: ...
    def contains(self, cs: Charset) -> bool: ...
    def decode(self, bb: ByteBuffer) -> CharBuffer: ...
    @staticmethod
    def defaultCharset() -> Charset: ...
    def displayName(self, locale: Optional[Locale]) -> AnyStr: ...
    def encode(self, arg: Union[Charset, AnyStr]) -> ByteBuffer: ...
    @staticmethod
    def forName(charsetName: AnyStr) -> Charset: ...
    def isRegistered(self) -> bool: ...
    @staticmethod
    def isSupported(charsetName: AnyStr) -> bool: ...
    def name(self) -> AnyStr: ...
    def newDecoder(self) -> CharsetDecoder: ...
    def newEncoder(self) -> CharsetEncoder: ...

class CharsetDecoder(Object):
    def charset(self) -> Charset: ...
    def decode(
        self,
        in_: ByteBuffer,
        out: Optional[CharBuffer] = ...,
        endOfInput: Optional[bool] = ...,
    ) -> CharBuffer: ...

class CharsetEncoder(Object):
    def charset(self) -> Charset: ...
    def encode(
        self,
        in_: ByteBuffer,
        out: Optional[ByteBuffer] = ...,
        endOfInput: Optional[bool] = ...,
    ) -> Union[ByteBuffer, CoderResult]: ...

class CoderResult(Object):
    OVERFLOW: CoderResult
    UNDERFLOW: CoderResult
    def isError(self) -> bool: ...
    def isMalformed(self) -> bool: ...
    def isOverflow(self) -> bool: ...
    def isUnderFlow(self) -> bool: ...
    def isUnmappable(self) -> bool: ...
    def length(self) -> int: ...
    @staticmethod
    def malformedForLength(length: int) -> CoderResult: ...
    def throwException(self) -> None: ...
    @staticmethod
    def unmappableForLength(length: int) -> CoderResult: ...



from typing import Any, Dict, List, Optional

from com.inductiveautomation.ignition.common import BasicDataset
from dev.coatl.helper.types import AnyStr

def executeAndDistribute(
    path: AnyStr,
    project: AnyStr = ...,
    parameters: Optional[Dict[AnyStr, int]] = ...,
    action: Optional[AnyStr] = ...,
    actionSettings: Optional[Dict[AnyStr, Any]] = ...,
) -> None: ...
def executeReport(
    path: AnyStr,
    project: AnyStr = ...,
    parameters: Optional[Dict[AnyStr, int]] = ...,
    fileType: AnyStr = ...,
) -> Any: ...
def getReportNamesAsDataset(
    project: Optional[AnyStr] = ..., includeReportName: bool = ...
) -> BasicDataset: ...
def getReportNamesAsList(project: Optional[AnyStr] = ...) -> List[AnyStr]: ...



from typing import Any, Dict, List, Optional, Union

from dev.coatl.helper.types import AnyStr
from org.python.core import PyObject

def aggregate(
    connector: AnyStr,
    collection: AnyStr,
    aggregate: List[Dict[AnyStr, Any]],
    collation: Optional[Dict[AnyStr, Any]] = ...,
) -> List[Dict[AnyStr, Any]]: ...
def deleteMany(
    connector: AnyStr,
    collection: AnyStr,
    filter: Dict[AnyStr, Any],
    options: Optional[Dict[AnyStr, Any]] = ...,
) -> Dict[AnyStr, Any]: ...
def deleteOne(
    connector: AnyStr,
    collection: AnyStr,
    filter: Dict[AnyStr, Any],
    options: Optional[Dict[AnyStr, Any]] = ...,
) -> Dict[AnyStr, Any]: ...
def find(
    connector: AnyStr,
    collection: AnyStr,
    filter: Dict[AnyStr, Any],
    project: Optional[Dict[AnyStr, Any]] = ...,
    sort: Optional[Dict[AnyStr, Any]] = ...,
    collation: Optional[Dict[AnyStr, Any]] = ...,
    limit: Optional[int] = ...,
    skip: Optional[int] = ...,
) -> List[Dict[AnyStr, Any]]: ...
def findOne(
    connector: AnyStr,
    collection: AnyStr,
    filter: Dict[AnyStr, Any],
    project: Optional[Dict[AnyStr, Any]] = ...,
) -> Dict[AnyStr, Any]: ...
def insertMany(
    connector: AnyStr,
    collection: AnyStr,
    document: List[Dict[AnyStr, Any]],
    options: Optional[Dict[AnyStr, Any]] = ...,
) -> List[PyObject]: ...
def insertOne(
    connector: AnyStr,
    collection: AnyStr,
    document: Dict[AnyStr, Any],
    options: Optional[Dict[AnyStr, Any]] = ...,
) -> PyObject: ...
def listCollectionNames(connector: AnyStr) -> List[AnyStr]: ...
def listConnectorInfo() -> List[Dict[AnyStr, Any]]: ...
def replaceOne(
    connector: AnyStr,
    collection: AnyStr,
    replacement: Dict[AnyStr, Any],
    options: Optional[Dict[AnyStr, Any]] = ...,
) -> Dict[AnyStr, Any]: ...
def updateMany(
    connector: AnyStr,
    collection: AnyStr,
    filter: Dict[AnyStr, Any],
    updates: Union[Dict[AnyStr, Any], List[Dict[AnyStr, Any]]],
    options: Optional[Dict[AnyStr, Any]] = ...,
) -> Dict[AnyStr, Any]: ...
def updateOne(
    connector: AnyStr,
    collection: AnyStr,
    filter: Dict[AnyStr, Any],
    updates: Union[Dict[AnyStr, Any], List[Dict[AnyStr, Any]]],
    options: Optional[Dict[AnyStr, Any]] = ...,
) -> Dict[AnyStr, Any]: ...



from typing import Any

from dev.coatl.helper.types import AnyStr
from enum import Enum
from java.io import Closeable, Flushable, Reader, Writer
from java.lang import Object

class JsonReader(Object, Closeable):
    def __init__(self, in_: Reader) -> None: ...
    def beginArray(self) -> None: ...
    def beginObject(self) -> None: ...
    def close(self) -> None: ...
    def endArray(self) -> None: ...
    def endObject(self) -> None: ...
    def getPath(self) -> AnyStr: ...
    def hasNext(self) -> bool: ...
    def isLenient(self) -> bool: ...
    def nextBoolean(self) -> bool: ...
    def nextDouble(self) -> float: ...
    def nextInt(self) -> int: ...
    def nextLong(self) -> long: ...
    def nextName(self) -> AnyStr: ...
    def nextNull(self) -> None: ...
    def nextString(self) -> AnyStr: ...
    def peek(self) -> JsonToken: ...
    def setLenient(self, lenient: bool) -> None: ...
    def skipValue(self) -> None: ...

class JsonToken(Enum):
    BEGIN_ARRAY: JsonToken
    BEGIN_OBJECT: JsonToken
    BOOLEAN: JsonToken
    END_ARRAY: JsonToken
    END_DOCUMENT: JsonToken
    END_OBJECT: JsonToken
    NAME: JsonToken
    NULL: JsonToken
    NUMBER: JsonToken
    STRING: JsonToken

class JsonWriter(Object, Closeable, Flushable):
    def __init__(self, out: Writer) -> None: ...
    def beginArray(self) -> JsonWriter: ...
    def beginObject(self) -> JsonWriter: ...
    def close(self) -> None: ...
    def endArray(self) -> JsonWriter: ...
    def endObject(self) -> JsonWriter: ...
    def flush(self) -> None: ...
    def getSerializeNulls(self) -> bool: ...
    def isHtmlSafe(self) -> bool: ...
    def isLenient(self) -> bool: ...
    def jsonValue(self, value: AnyStr) -> JsonWriter: ...
    def name(self, name: AnyStr) -> JsonWriter: ...
    def setHtmlSafe(self, htmlSafe: bool) -> None: ...
    def setIndent(self, indent: AnyStr) -> None: ...
    def setLenient(self, lenient: bool) -> None: ...
    def setSerializeNulls(self, serializeNulls: bool) -> None: ...
    def value(self, arg: Any) -> JsonWriter: ...



from typing import Iterable, Mapping

import ch.qos.logback.classic
from dev.coatl.helper.types import AnyStr
from java.lang import Enum

class LogFilterSettings:
    def addPropertyFilter(self, key: AnyStr, value: AnyStr) -> None: ...
    def clearPropertyLevel(self, key: AnyStr, value: AnyStr) -> None: ...
    def clearPropertyLevels(self) -> None: ...
    def propertyFilterSettings(self) -> Mapping[AnyStr, Mapping[AnyStr, Level]]: ...
    def removePropertyFilter(self, key: AnyStr, value: AnyStr) -> None: ...
    def setLevel(self, logger: AnyStr, level: Level) -> None: ...
    def setPropertyLevel(self, key: AnyStr, value: AnyStr, level: Level) -> None: ...

class Level(Enum):
    def toLevel(self, value: ch.qos.logback.classic.Level) -> Level: ...
    def toLogBack(self) -> ch.qos.logback.classic.Level: ...
    @staticmethod
    def values() -> Iterable[Level]: ...



from copy import PyStringMap as PyStringMap  # noqa: F401
from typing import Any, Iterable, Iterator, List, Mapping, Optional, Tuple, Union

from dev.coatl.helper.types import AnyStr
from enum import Enum
from java.io import PrintWriter
from java.lang import Class, Object, RuntimeException, StringBuilder
from java.util import Collection
from java.util import Iterator as JIterator
from java.util import ListIterator, Properties
from org.python.expose import TypeBuilder

class PyObject(Object):
    gcMonitorGlobal: bool
    TYPE: PyType
    def __init__(self, objtype: Optional[PyType] = ...) -> None: ...
    def __abs__(self) -> PyObject: ...
    def __add__(self, other: PyObject) -> PyObject: ...
    def __and__(self, other: PyObject) -> PyObject: ...
    def __call__(self, *args: Any, **kwargs: Any) -> PyObject: ...
    def __coerce__(self, pyo: PyObject) -> PyObject: ...
    def __coerce_ex__(self, o: PyObject) -> Object: ...
    def __complex__(self) -> complex: ...
    def __contains__(self, o: PyObject) -> bool: ...
    def __delete__(self, obj: PyObject) -> None: ...
    def __delitem__(self, key: PyObject) -> None: ...
    def __delslice__(
        self, start: PyObject, stop: PyObject, step: Optional[PyObject] = ...
    ) -> None: ...
    def __dir__(self) -> PyObject: ...
    def __div__(self, other: PyObject) -> PyObject: ...
    def __ensure_finalizer__(self) -> None: ...
    def __findattr__(self, name: str) -> PyObject: ...
    def __findattr_ex__(self, name: str) -> PyObject: ...
    def __finditem__(self, key: str) -> PyObject: ...
    def __float__(self) -> float: ...
    def __floordiv__(self, other: PyObject) -> PyObject: ...
    def __get__(self, obj: PyObject, type: PyObject) -> PyObject: ...
    def __getattr__(self, name: str) -> PyObject: ...
    def __getitem__(self, key: Union[int, PyObject]) -> PyObject: ...
    def __getnewargs__(self) -> Tuple[Any, ...]: ...
    def __getslice__(
        self, start: PyObject, stop: PyObject, step: Optional[PyObject] = ...
    ) -> None: ...
    def __hex__(self) -> str: ...
    def __iadd__(self, other: PyObject) -> PyObject: ...
    def __iand__(self, other: PyObject) -> PyObject: ...
    def __idiv__(self, other: PyObject) -> PyObject: ...
    def __idivmod__(self, other: PyObject) -> PyObject: ...
    def __ifloordiv__(self, other: PyObject) -> PyObject: ...
    def __ilshift__(self, other: PyObject) -> PyObject: ...
    def __imod__(self, other: PyObject) -> PyObject: ...
    def __imul__(self, other: PyObject) -> PyObject: ...
    def __index__(self) -> PyObject: ...
    def __int__(self) -> PyObject: ...
    def __invert__(self) -> PyObject: ...
    def __ior__(self, other: PyObject) -> PyObject: ...
    def __ipow__(
        self, other: PyObject, dummy: Optional[PyObject] = ...
    ) -> PyObject: ...
    def __irshift__(self, other: PyObject) -> PyObject: ...
    def __isub__(self, other: PyObject) -> PyObject: ...
    def __iter__(self) -> Iterator[Any]: ...
    def __iternext__(self) -> PyObject: ...
    def __itruediv__(self, other: PyObject) -> PyObject: ...
    def __ixor__(self, other: PyObject) -> PyObject: ...
    def __le__(self, other: PyObject) -> PyObject: ...
    def __long__(self) -> PyObject: ...
    def __lshift__(self, other: PyObject) -> PyObject: ...
    def __mod__(self, other: PyObject) -> PyObject: ...
    def __mul__(self, other: PyObject) -> PyObject: ...
    def __neg__(self) -> PyObject: ...
    def __nonzero__(self) -> PyObject: ...
    def __not__(self) -> PyObject: ...
    def __oct__(self) -> PyObject: ...
    def __or__(self, other: PyObject) -> PyObject: ...
    def __pos__(self) -> PyObject: ...
    def __pow__(self, o2: PyObject, o3: Optional[PyObject] = ...) -> PyObject: ...
    def __radd__(self, other: PyObject) -> PyObject: ...
    def __rand__(self, other: PyObject) -> PyObject: ...
    def __rdiv__(self, other: PyObject) -> PyObject: ...
    def __rdivmod__(self, other: PyObject) -> PyObject: ...
    def __rfloordiv__(self, other: PyObject) -> PyObject: ...
    def __rlshift__(self, other: PyObject) -> PyObject: ...
    def __rmod__(self, other: PyObject) -> PyObject: ...
    def __rmul__(self, other: PyObject) -> PyObject: ...
    def __ror__(self, other: PyObject) -> PyObject: ...
    def __rpow__(self, other: PyObject) -> PyObject: ...
    def __rrshift__(self, other: PyObject) -> PyObject: ...
    def __rshift__(self, other: PyObject) -> PyObject: ...
    def __rsub__(self, other: PyObject) -> PyObject: ...
    def __rtruediv__(self, other: PyObject) -> PyObject: ...
    def __rxor__(self, other: PyObject) -> PyObject: ...
    def __set__(self, obj: PyObject, value: PyObject) -> None: ...
    def __setitem__(self, key: Union[int, PyObject, str], value: PyObject) -> None: ...
    def __setslice__(self, *args: Any) -> None: ...
    def __sub__(self, other: PyObject) -> PyObject: ...
    def __tojava__(self, c: Class) -> Object: ...
    def __truediv__(self, other: PyObject) -> PyObject: ...
    def __trunc__(self) -> PyObject: ...
    def __unicode__(self) -> unicode: ...
    def __xor__(self, other: PyObject) -> PyObject: ...
    def asDouble(self) -> float: ...
    def asIndex(self, err: Optional[PyObject] = ...) -> int: ...
    def asInt(self, index: Optional[int] = ...) -> int: ...
    def asIterable(self) -> Iterable[PyObject]: ...
    def asLong(self, index: Optional[int] = ...) -> long: ...
    def asName(self, arg: Union[int, PyObject]) -> AnyStr: ...
    def asString(self, index: Optional[int] = ...) -> AnyStr: ...
    def asStringOrNull(self, index: Optional[int] = ...) -> AnyStr: ...
    def bit_length(self) -> int: ...
    def conjugate(self) -> PyObject: ...
    def delDict(self) -> None: ...
    def delType(self) -> None: ...
    def dispatch__init__(self, *args: Any, **kwargs: Any) -> None: ...
    def fastGetClass(self) -> PyObject: ...
    def fastGetDict(self) -> PyObject: ...
    def getDict(self) -> PyObject: ...
    def getType(self) -> PyType: ...
    def implementsDescrDelete(self) -> bool: ...
    def implementsDescrGet(self) -> bool: ...
    def implementsDescrSet(self) -> bool: ...
    def invoke(self, *args: Any, **kwargs: Any) -> PyObject: ...
    def isCallable(self) -> bool: ...
    def isDataDescr(self) -> bool: ...
    def isIndex(self) -> bool: ...
    def isInteger(self) -> bool: ...
    def isMappingType(self) -> bool: ...
    def isNumberType(self) -> bool: ...
    def isSequenceType(self) -> bool: ...
    def noAttributeError(self, name: AnyStr) -> None: ...
    @staticmethod
    def object___subclasshook__(type: PyType, subclass: PyObject) -> PyObject: ...
    def readonlyAttributeError(self, name: AnyStr) -> None: ...
    def setDict(self, newDict: PyObject) -> None: ...
    def setType(self, type: PyType) -> None: ...

class CodeFlag(Enum):
    CO_FUTURE_ABSOLUTE_IMPORT: int
    CO_FUTURE_DIVISION: int
    CO_FUTURE_PRINT_FUNCTION: int
    CO_FUTURE_UNICODE_LITERALS: int
    CO_FUTURE_WITH_STATEMENT: int
    CO_GENERATOR: int
    CO_GENERATOR_ALLOWED: int
    CO_NESTED: int
    CO_NEWLOCALS: int
    CO_OPTIMIZED: int
    CO_VARARGS: int
    CO_VARKEYWORDS: int
    flag: int
    def isFlagBitSetIn(self, flags: int) -> bool: ...
    @staticmethod
    def valueOf(name: AnyStr) -> CodeFlag: ...
    @staticmethod
    def values() -> List[CodeFlag]: ...

class CompilerFlags(Object):
    dont_imply_dedent: bool
    encoding: AnyStr
    only_ast: bool
    PyCF_DONT_IMPLY_DEDENT: int
    PyCF_ONLY_AST: int
    PyCF_SOURCE_IS_UTF8: int
    source_is_utf8: bool
    def __init__(self, co_flags: Optional[int] = ...) -> None: ...
    def combine(self, flags: Union[CompilerFlags, int]) -> CompilerFlags: ...
    @staticmethod
    def getCompilerFlags(
        flags: Union[CompilerFlags, int], frame: PyFrame
    ) -> CompilerFlags: ...
    def isFlagSet(self, flag: CodeFlag) -> bool: ...
    def toBits(self) -> int: ...

class PyCode(PyObject):
    co_name: AnyStr
    def call(self, *args: Any) -> None: ...

class PyBaseCode(PyCode):
    co_argcount: int
    co_cellvars: List[AnyStr]
    co_filename: AnyStr
    co_firstlineno: int
    co_flags: CompilerFlags
    co_freevars: List[AnyStr]
    co_nlocals: int
    co_varnames: List[AnyStr]
    jy_npurecell: int
    varargs: bool
    varkwargs: bool
    def getCompilerFlags(self) -> CompilerFlags: ...
    def hasFreevars(self) -> bool: ...

class PyBuiltinCallable(PyObject):
    def bind(self, o: PyObject) -> PyBuiltinCallable: ...
    def fastGetName(self) -> PyObject: ...
    def getDoc(self) -> AnyStr: ...
    def getModule(self) -> PyObject: ...
    def getSelf(self) -> PyObject: ...
    def makeCall(self) -> PyObject: ...
    def setInfo(self, info: PyBuiltinCallable.Info) -> None: ...

    class Info:
        def getMaxargs(self) -> int: ...
        def getMinargs(self) -> int: ...
        def getName(self) -> AnyStr: ...
        def unexpectedCall(self, nargs: int, keywords: bool) -> PyException: ...

class PyBuiltinMethod(PyBuiltinCallable):
    def bind(self, o: PyObject) -> PyBuiltinCallable: ...
    def makeDescriptor(self, t: PyType) -> PyMethodDescr: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...

class PyCell(PyObject):
    ob_ref: PyObject
    def __init__(self) -> None: ...
    def getCellContents(self) -> PyObject: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...

class PyDescriptor(PyObject, PyBuiltinCallable.Info):
    def __init__(self, t: PyType, func: PyBuiltinCallable) -> None: ...
    def getDoc(self) -> AnyStr: ...
    def getMaxargs(self) -> int: ...
    def getMinargs(self) -> int: ...
    def getName(self) -> AnyStr: ...
    def getObjClass(self) -> PyObject: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...
    def unexpectedCall(self, nargs: int, keywords: bool) -> PyException: ...

class PyException(RuntimeException):
    traceback: Optional[PyTraceback]
    type: Optional[PyObject]
    value: Optional[Union[PyObject, AnyStr]]
    def __init__(
        self,
        type_: Optional[PyObject] = ...,
        value: Optional[Union[PyObject, AnyStr]] = ...,
        traceback: Optional[PyTraceback] = ...,
    ) -> None: ...
    @staticmethod
    def doRaise(
        type_: PyObject, value: PyObject, traceback: PyObject
    ) -> PyException: ...
    def exceptionClassName(self, obj: PyObject) -> AnyStr: ...
    def isExceptionClass(self, obj: PyObject) -> bool: ...
    def match(self, exc: PyObject) -> bool: ...
    def normalize(self) -> None: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def super__printStackTrace(self, w: PrintWriter) -> None: ...
    def tracebackHere(self, here: PyFrame, isFinally: Optional[bool] = ...) -> None: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...

class PyFrame(PyObject):
    f_back: PyFrame
    f_builtins: PyObject
    f_code: PyBaseCode
    f_env: List[PyCell]
    f_exits: List[PyObject]
    f_fastlocals: List[PyObject]
    f_globals: PyObject
    f_lasti: int
    f_lineno: int
    f_locals: PyObject
    f_ncells: int
    f_nfreevars: int
    f_savedlocals: List[Object]
    tracefunc: TraceFunction
    def __init__(self, *args: Any) -> None: ...
    def checkGeneratorInput(self) -> Object: ...
    def delglobal(self, index: AnyStr) -> None: ...
    def dellocal(self, index: Union[int, AnyStr]) -> None: ...
    def delTrace(self) -> None: ...
    def getclosure(self, index: int) -> PyObject: ...
    def getderef(self, index: int) -> PyObject: ...
    def getf_locals(self) -> PyObject: ...
    def getGeneratorInput(self) -> Object: ...
    def getglobal(self, index: AnyStr) -> PyObject: ...
    def getLine(self) -> int: ...
    def getlocal(self, index: int) -> PyObject: ...
    def getLocals(self) -> PyObject: ...
    def getname(self, index: AnyStr) -> PyObject: ...
    def getTrace(self) -> PyObject: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def setderef(self, index: int, value: PyObject) -> None: ...
    def setglobal(self, index: AnyStr, value: PyObject) -> None: ...
    def setline(self, line: int) -> None: ...
    def setlocal(self, index: Union[int, AnyStr], value: PyObject) -> None: ...
    def setTrace(self, trace: PyObject) -> None: ...
    def to_cell(self, parm_index: int, env_index: int) -> None: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...

class PyFunction(PyObject):
    def __init__(self, *args: Any) -> None: ...

class PyInteger(PyObject):
    def __init__(self, *args: Any) -> None: ...

class PyMethodDescr(PyDescriptor):
    def __init__(self, t: PyType, func: PyBuiltinCallable) -> None: ...

class PyNewWrapper(PyBuiltinMethod):
    for_type: PyType
    def __init__(self, *args: Any) -> None: ...
    def getWrappedType(self) -> PyType: ...
    def new_impl(
        self, init: bool, subtype: PyType, *args: Any, **kwargs: Any
    ) -> PyObject: ...
    def setWrappedType(self, type_: PyType) -> None: ...

class PySequence(PyObject): ...

class PySequenceList(PySequence):
    def add(self, *args: Any) -> Optional[bool]: ...
    def addAll(self, *args: Any) -> bool: ...
    def clear(self) -> None: ...
    def contains(self, o: Object) -> bool: ...
    def containsAll(self, c: Collection) -> bool: ...
    def get(self, index: int) -> Object: ...
    def getArray(self) -> List[PyObject]: ...
    def indexOf(self, o: Object) -> int: ...
    def isEmpty(self) -> bool: ...
    def iterator(self) -> JIterator: ...
    def lastIndexOf(self, o: Object) -> int: ...
    def listIterator(self, index: Optional[int] = ...) -> ListIterator: ...
    def pyadd(self, *args: Any) -> Optional[bool]: ...
    def pyget(self, index: int) -> PyObject: ...
    def pyset(self, index: int, element: PyObject) -> None: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def remove(self, *args: Any) -> Union[bool, None, Object]: ...
    def removeAll(self, c: Collection) -> bool: ...
    def retainAll(self, c: Collection) -> bool: ...
    def set(self, index: int, element: Object) -> Object: ...
    def size(self) -> int: ...
    def subList(self, fromIndex: int, toIndex: int) -> List[PyObject]: ...
    def toArray(self, a: Optional[List[Object]] = ...) -> List[Object]: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...

class PyList(PySequenceList):
    def __init__(self, *args: Any) -> None: ...
    def add(self, *args: Any) -> Optional[bool]: ...
    def addAll(self, *args: Any) -> bool: ...
    def append(self, o: PyObject) -> None: ...
    def clear(self) -> None: ...
    def contains(self, o: Object) -> bool: ...
    def containsAll(self, c: Collection) -> bool: ...
    def count(self, o: PyObject) -> int: ...
    def extend(self, o: PyObject) -> None: ...
    @staticmethod
    def fromList(list_: List[PyObject]) -> PyList: ...
    def get(self, index: int) -> Object: ...
    def getArray(self) -> List[PyObject]: ...
    def index(self, o: PyObject, *args: int) -> int: ...
    def indexOf(self, o: Object) -> int: ...
    def insert(self, o: PyObject) -> None: ...
    def isEmpty(self) -> bool: ...
    def iterator(self) -> JIterator: ...
    def lastIndexOf(self, o: Object) -> int: ...
    def listIterator(self, index: Optional[int] = ...) -> ListIterator: ...
    def pyadd(self, *args: Any) -> Optional[bool]: ...
    def pyget(self, index: int) -> PyObject: ...
    def pyset(self, index: int, element: PyObject) -> None: ...
    def remove(self, *args: Any) -> Union[bool, None, Object]: ...
    def removeAll(self, c: Collection) -> bool: ...
    def retainAll(self, c: Collection) -> bool: ...
    def reverse(self) -> None: ...
    def set(self, index: int, element: Object) -> Object: ...
    def size(self) -> int: ...
    def sort(self, *args: PyObject) -> None: ...
    def subList(self, fromIndex: int, toIndex: int) -> List[PyObject]: ...
    def toArray(self, a: Optional[List[Object]] = ...) -> List[Object]: ...

class PyModule(PyObject): ...

class PyString(PyObject):
    def __init__(self, *args: Any) -> None: ...

class PySystemState(PyObject):
    def argv(self) -> PyList: ...
    @staticmethod
    def builtin_module_names() -> PyTuple: ...
    def builtins(self) -> PyObject: ...
    @staticmethod
    def byteorder() -> PyString: ...
    @staticmethod
    def copyright() -> PyObject: ...
    def dont_write_bytecode(self) -> bool: ...
    @staticmethod
    def exec_prefix() -> PyObject: ...
    def executable(self) -> PyObject: ...
    @staticmethod
    def flags() -> Class: ...
    @staticmethod
    def float_info() -> PyObject: ...
    @staticmethod
    def float_repr_style() -> PyString: ...
    @staticmethod
    def hexversion() -> int: ...
    def last_traceback(self) -> PyObject: ...
    def last_type(self) -> PyObject: ...
    def last_value(self) -> PyObject: ...
    @staticmethod
    def long_info() -> PyObject: ...
    @staticmethod
    def maxint() -> int: ...
    @staticmethod
    def maxsize() -> int: ...
    @staticmethod
    def maxunicode() -> int: ...
    def meta_path(self) -> PyList: ...
    @staticmethod
    def minint() -> int: ...
    def modules(self) -> PyObject: ...
    def modules_reloading(self) -> Mapping[AnyStr, PyModule]: ...
    def path(self) -> PyList: ...
    def path_hooks(self) -> PyList: ...
    def path_importer_cache(self) -> PyObject: ...
    def platform(self) -> PyObject: ...
    @staticmethod
    def prefix() -> PyObject: ...
    def ps1(self) -> PyObject: ...
    def ps2(self) -> PyObject: ...
    @staticmethod
    def py3kwarning() -> bool: ...
    @staticmethod
    def registry() -> Properties: ...
    def stderr(self) -> PyObject: ...
    def stdin(self) -> PyObject: ...
    def stdout(self) -> PyObject: ...
    @staticmethod
    def subversion() -> PyTuple: ...
    @staticmethod
    def version() -> PyString: ...
    @staticmethod
    def version_info() -> PyVersionInfo: ...
    def warnoptions(self) -> PyList: ...

class PyTraceback(PyObject):
    tb_frame: PyFrame
    tb_lineno: int
    tb_next: PyObject
    def __init__(self, next: PyTraceback, frame: PyFrame) -> None: ...
    def dumpStack(self, buf: Optional[StringBuilder] = ...) -> Optional[AnyStr]: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...

class PyTuple(PySequenceList):
    def __init__(self, *args: Any) -> None: ...
    def add(self, *args: Any) -> Optional[bool]: ...
    def addAll(self, *args: Any) -> bool: ...
    def clear(self) -> None: ...
    def contains(self, o: Object) -> bool: ...
    def containsAll(self, c: Collection) -> bool: ...
    def count(self, value: PyObject) -> int: ...
    @staticmethod
    def fromIterable(iterable: PyObject) -> PyTuple: ...
    def get(self, index: int) -> Object: ...
    def getArray(self) -> List[PyObject]: ...
    def index(self, value: PyObject, *args: int) -> int: ...
    def indexOf(self, o: Object) -> int: ...
    def isEmpty(self) -> bool: ...
    def iterator(self) -> JIterator: ...
    def lastIndexOf(self, o: Object) -> int: ...
    def listIterator(self, index: Optional[int] = ...) -> ListIterator: ...
    def pyadd(self, *args: Any) -> Optional[bool]: ...
    def pyget(self, index: int) -> PyObject: ...
    def pyset(self, index: int, element: PyObject) -> None: ...
    def remove(self, *args: Any) -> Union[bool, None, Object]: ...
    def removeAll(self, c: Collection) -> bool: ...
    def retainAll(self, c: Collection) -> bool: ...
    def set(self, index: int, element: Object) -> Object: ...
    def size(self) -> int: ...
    def subList(self, fromIndex: int, toIndex: int) -> List[PyObject]: ...
    def toArray(self, a: Optional[List[Object]] = ...) -> List[Object]: ...
    def tuple___iter__(self) -> PyObject: ...

class PyType(PyObject):
    @staticmethod
    def addBuilder(c: Class, builder: TypeBuilder) -> None: ...
    def addMethod(self, meth: PyBuiltinMethod) -> None: ...
    def compatibleForAssignment(self, other: PyType, attribute: AnyStr) -> None: ...
    def delBases(self) -> None: ...
    def delModule(self) -> None: ...
    @staticmethod
    def ensureBootstrapped() -> bool: ...
    @staticmethod
    def ensureDoc(arg: PyObject) -> None: ...
    @staticmethod
    def ensureModule(arg: PyObject) -> None: ...
    def fastGetName(self) -> AnyStr: ...
    @staticmethod
    def fromClass(c: Class, hardRef: bool = ...) -> PyType: ...
    def getAbstractMethods(self) -> PyObject: ...
    def getBase(self) -> PyObject: ...
    def getBases(self) -> PyObject: ...
    def getDoc(self) -> PyObject: ...
    def getFlags(self) -> long: ...
    def getModule(self) -> PyObject: ...
    def getMro(self) -> Tuple[Any, ...]: ...
    def getName(self) -> AnyStr: ...
    def getNumSlots(self) -> int: ...
    def getProxyType(self) -> Class: ...
    def getStatic(self) -> PyObject: ...
    def instDict(self) -> PyObject: ...
    def isSubType(self, supertype: PyType) -> bool: ...
    def lookup_where(self, name: AnyStr, where: List[PyObject]) -> PyObject: ...
    def lookup(self, name: AnyStr) -> PyObject: ...
    def needsFinalizer(self) -> bool: ...
    @staticmethod
    def newType(
        new_: PyNewWrapper,
        metatype: PyType,
        name: AnyStr,
        bases: Tuple[Any, ...],
        dict_: PyObject,
    ) -> PyObject: ...
    def pyDelName(self) -> None: ...
    def pyGetName(self) -> PyObject: ...
    def pySetName(self, name: PyObject) -> None: ...
    def refersDirectlyTo(self, ob: PyObject) -> bool: ...
    def removeMethod(self, meth: PyBuiltinMethod) -> None: ...
    def setAbstractMethods(self, value: PyObject) -> None: ...
    def setBases(self, newBasesTuple: PyObject) -> None: ...
    def setName(self, name: AnyStr) -> None: ...
    def super_lookup(self, ref: PyType, name: AnyStr) -> PyObject: ...
    def traverse(self, visit: Visitproc, arg: Object) -> int: ...
    def type___eq__(self, other: PyObject) -> PyObject: ...
    def type___ge__(self, other: PyObject) -> PyObject: ...
    def type___gt__(self, other: PyObject) -> PyObject: ...
    def type___instancecheck__(self, inst: PyObject) -> bool: ...
    def type___le__(self, other: PyObject) -> PyObject: ...
    def type___lt__(self, other: PyObject) -> PyObject: ...
    def type___ne__(self, other: PyObject) -> PyObject: ...
    def type___subclasscheck__(self, inst: PyObject) -> bool: ...
    def type___subclasses__(self) -> PyObject: ...

class TraceFunction(Object):
    def traceCall(self, frame: PyFrame) -> TraceFunction: ...
    def traceException(self, frame: PyFrame, exc: PyException) -> TraceFunction: ...
    def traceLine(self, frame: PyFrame, line: int) -> TraceFunction: ...
    def traceReturn(self, frame: PyFrame, ret: PyObject) -> TraceFunction: ...

class PyVersionInfo(PyTuple): ...

class Visitproc:
    def visit(self, obj: PyObject, arg: Object) -> int: ...



from typing import Any, Mapping, Optional, Set

from dev.coatl.helper.types import AnyStr
from java.lang import Object

class NamedQueryManager:
    def beginTransaction(
        self, project: AnyStr, datasource: AnyStr, isolationLevel: int, timeout: long
    ) -> AnyStr: ...
    def clearAllCaches(self, project: AnyStr) -> None: ...
    def clearCache(self, project: AnyStr, queryPaths: Set[AnyStr]) -> None: ...
    def execute(self, *args: Any) -> Object: ...
    def executeSFquery(
        self, project: AnyStr, path: AnyStr, parameters: Mapping[AnyStr, Object]
    ) -> Object: ...
    def getQueryFromPath(self, project: AnyStr, queryPath: AnyStr) -> NamedQuery: ...

class NamedQuery(Object):
    def __init__(self, nq: Optional[NamedQuery] = ...) -> None: ...



from typing import Dict, Optional, Set

from dev.coatl.helper.types import AnyStr
from java.lang import CharSequence, Object

class Clock(Object):
    @staticmethod
    def offset(baseClock: Instant, offsetDuration: ZoneId) -> Clock: ...
    @staticmethod
    def systemDefaultZone() -> Clock: ...
    @staticmethod
    def systemUTC() -> Clock: ...
    @staticmethod
    def tick(baseClock: Clock, tickDuration: Duration) -> Clock: ...
    @staticmethod
    def tickMillis(zone: ZoneId) -> Clock: ...
    @staticmethod
    def tickMinutes(zone: ZoneId) -> Clock: ...
    @staticmethod
    def tickSeconds(zone: ZoneId) -> Clock: ...

class Duration(Object):
    ZERO: Duration
    def toDays(self) -> long: ...
    def toDaysPart(self) -> long: ...
    def toHours(self) -> long: ...
    def toHoursPart(self) -> int: ...
    def toMillis(self) -> long: ...
    def toMillisPart(self) -> int: ...
    def toMinutes(self) -> long: ...
    def toMinutesPart(self) -> int: ...
    def toNanos(self) -> long: ...
    def toNanosPart(self) -> int: ...
    def toSeconds(self) -> long: ...
    def toSecondsPart(self) -> int: ...

class Instant(Object):
    EPOCH: Instant
    MAX: Instant
    MIN: Instant
    @staticmethod
    def now(clock: Optional[Clock] = ...) -> Instant: ...
    @staticmethod
    def ofEpochMilli(epochMilli: long) -> Instant: ...
    @staticmethod
    def ofEpochSecond(
        epochSecond: long, nanoAdjustment: Optional[long] = ...
    ) -> Instant: ...
    @staticmethod
    def parse(text: CharSequence) -> Instant: ...

class ZoneId(Object):
    SHORT_IDS: Dict[AnyStr, AnyStr]
    @staticmethod
    def getAvailableZoneIds() -> Set[AnyStr]: ...
    @staticmethod
    def of(
        zoneId: AnyStr, aliasMap: Optional[Dict[AnyStr, AnyStr]] = ...
    ) -> ZoneId: ...
    @staticmethod
    def ofOffset(prefix: AnyStr, offset: ZoneOffset) -> ZoneId: ...
    @staticmethod
    def systemDefault() -> ZoneId: ...

class ZoneOffset(Object):
    MAX: ZoneOffset
    MIN: ZoneOffset
    UTC: ZoneOffset
    @staticmethod
    def of(offsetId: AnyStr) -> ZoneOffset: ...
    @staticmethod
    def ofHours(hours: int) -> ZoneOffset: ...
    @staticmethod
    def ofHoursMinutes(hours: int, minutes: int) -> ZoneOffset: ...
    @staticmethod
    def ofHoursMinutesSeconds(hours: int, minutes: int, seconds: int) -> ZoneOffset: ...
    @staticmethod
    def ofTotalSeconds(totalSeconds: int) -> ZoneOffset: ...



from typing import List, Optional

from com.inductiveautomation.ignition.common import BasicDataset
from com.inductiveautomation.ignition.common.messages import UIResponse
from dev.coatl.helper.types import AnyStr
from java.util import Date

def getGroups() -> List[AnyStr]: ...
def queryAgentHistory(
    groupIds: Optional[List[AnyStr]] = ...,
    agentIds: Optional[List[AnyStr]] = ...,
    startDate: Optional[Date] = ...,
    endDate: Optional[Date] = ...,
    limit: int = ...,
) -> BasicDataset: ...
def queryAgentStatus(
    groupIds: Optional[List[AnyStr]] = ...,
    agentIds: Optional[List[AnyStr]] = ...,
    isConnected: bool = ...,
) -> BasicDataset: ...
def runTask(taskname: AnyStr) -> UIResponse: ...



from typing import Any

from dev.coatl.helper.types import AnyStr
from java.lang import Object

class EventBus(Object):
    def __init__(self, *args: Any) -> None: ...
    def identifier(self) -> AnyStr: ...
    def post(self, event: Object) -> None: ...
    def register(self, obj: Object) -> None: ...
    def unregister(self, obj: Object) -> None: ...



from enum import Enum

class DayOfWeek(Enum):
    MONDAY: int
    TUESDAY: int
    WEDNESDAY: int
    THURSDAY: int
    FRIDAY: int
    SATURDAY: int
    SUNDAY: int
    UNSPECIFIED: int

class MaxApduLength(Enum):
    UP_TO_50: int
    UP_TO_128: int
    UP_TO_206: int
    UP_TO_480: int
    UP_TO_1024: int
    UP_TO_1476: int

class MaxSegments(Enum):
    UNSPECIFIED: int
    UP_TO_2: int
    UP_TO_4: int
    UP_TO_8: int
    UP_TO_16: int
    UP_TO_32: int
    UP_TO_64: int
    MORE_THAN_64: int

class Month(Enum):
    JANUARY: int
    FEBRUARY: int
    MARCH: int
    APRIL: int
    MAY: int
    JUNE: int
    JULY: int
    AUGUST: int
    SEPTEMBER: int
    OCTOBER: int
    NOVEMBER: int
    DECEMBER: int
    ODD_MONTHS: int
    EVEN_MONTHS: int
    UNSPECIFIED: int



from typing import Any, Optional, Set, Union

from java.lang import AutoCloseable, Object
from java.nio import ByteBuffer, MappedByteBuffer
from java.util.function import Consumer

class Channel(AutoCloseable):
    def close(self) -> None: ...
    def isOpen(self) -> bool: ...

class ReadableByteChannel(Channel):
    def read(self, dst: ByteBuffer) -> int: ...

class WriteableByteChannel(Channel):
    def write(self, src: ByteBuffer) -> int: ...

class FileChannel(Object, Channel):
    def force(self, metaData: bool) -> None: ...
    def lock(self) -> FileLock: ...
    def map(
        self, mode: FileChannel.MapMode, position: long, size: long
    ) -> MappedByteBuffer: ...
    @staticmethod
    def open(*args: Any) -> FileChannel: ...
    def position(
        self, newPosition: Optional[long] = ...
    ) -> Union[FileChannel, long]: ...
    def read(self, *args: Any) -> Union[int, long]: ...
    def size(self) -> long: ...
    def transferFrom(
        self, src: ReadableByteChannel, position: long, count: long
    ) -> long: ...
    def transferTo(
        self, position: long, count: long, target: WriteableByteChannel
    ) -> long: ...
    def truncate(self, size: long) -> FileChannel: ...
    def tryLock(
        self,
        position: Optional[long] = ...,
        size: Optional[long] = ...,
        shared: Optional[bool] = ...,
    ) -> FileLock: ...
    def write(self, *args: Any) -> Union[int, long]: ...

    class MapMode(Object):
        PRIVATE: FileChannel.MapMode
        READ_ONLY: FileChannel.MapMode
        READ_WRITE: FileChannel.MapMode

class FileLock(Object, AutoCloseable):
    def acquiredBy(self) -> Channel: ...
    def channel(self) -> FileChannel: ...
    def close(self) -> None: ...
    def isShared(self) -> bool: ...
    def isValid(self) -> bool: ...
    def overlaps(self, position: long, size: long) -> bool: ...
    def position(self) -> long: ...
    def release(self) -> None: ...
    def size(self) -> long: ...

class SeekableByteChannel(ReadableByteChannel, WriteableByteChannel):
    def position(
        self, newPosition: Optional[long] = ...
    ) -> Union[long, SeekableByteChannel]: ...
    def size(self) -> long: ...
    def truncate(self, size: long) -> SeekableByteChannel: ...

class SelectableChannel(Object, AutoCloseable):
    def close(self) -> None: ...
    def blockingLock(self) -> Object: ...
    def configureBlocking(self) -> SelectableChannel: ...
    def isBlocking(self) -> bool: ...
    def isRegistered(self) -> bool: ...
    def keyFor(self, sel: Selector) -> SelectionKey: ...
    def provider(self) -> Object: ...
    def register(
        self, sel: Selector, ops: int, att: Optional[Object] = ...
    ) -> SelectionKey: ...
    def validOps(self) -> int: ...

class SelectionKey(Object):
    OP_ACCEPT: int
    OP_CONNECT: int
    OP_READ: int
    OP_WRITE: int
    def attach(self, ob: Object) -> Object: ...
    def attachment(self) -> Object: ...
    def cancel(self) -> None: ...
    def channel(self) -> SelectableChannel: ...
    def interestOps(self, ops: Optional[int] = ...) -> Union[int, SelectionKey]: ...
    def interestOpsAnd(self, ops: int) -> int: ...
    def interestOpsOr(self, ops: int) -> int: ...
    def isAcceptable(self) -> bool: ...
    def isConnectable(self) -> bool: ...
    def isReadable(self) -> bool: ...
    def isValid(self) -> bool: ...
    def isWriteable(self) -> bool: ...
    def readyOps(self) -> int: ...
    def selector(self) -> Selector: ...

class Selector(Object, AutoCloseable):
    def close(self) -> None: ...
    def isOpen(self) -> bool: ...
    def keys(self) -> Set[SelectionKey]: ...
    @staticmethod
    def open() -> Selector: ...
    def provider(self) -> Object: ...
    def select(self, *args: Any) -> int: ...
    def selectedKeys(self) -> Set[SelectionKey]: ...
    def selectNow(self, action: Optional[Consumer] = ...) -> int: ...
    def wakeup(self) -> Selector: ...

class SocketChannel(SelectableChannel):
    def bind(self, local: Any) -> SocketChannel: ...
    def connect(self, remote: Any) -> bool: ...
    def finishConnect(self) -> bool: ...
    def getLocalAddress(self) -> Any: ...
    def getRemoteAddress(self) -> Any: ...
    def isConnected(self) -> bool: ...
    def isConnectionPending(self) -> bool: ...
    def open(self, remote: Optional[Any] = ...) -> SocketChannel: ...
    def read(self, *args: Any) -> Union[int, long]: ...
    def setOption(self, name: Any, value: Any) -> SocketChannel: ...
    def shutdownInput(self) -> SocketChannel: ...
    def shutdownOutput(self) -> SocketChannel: ...
    def socket(self) -> Any: ...
    def write(self, *args: Any) -> Union[int, long]: ...



from typing import List, Optional

from dev.coatl.helper.types import AnyNum, AnyStr

NUL: int
PULSE_ON: int
PULSE_OFF: int
LATCH_ON: int
LATCH_OFF: int
CLOSE: int
TRIP: int

def directOperateAnalog(
    deviceName: AnyStr, index: int, value: AnyNum, variation: Optional[int] = ...
) -> int: ...
def directOperateBinary(
    deviceName: AnyStr,
    indexes: List[int],
    opType: int,
    tcCode: Optional[int] = ...,
    count: Optional[int] = ...,
    onTime: Optional[int] = ...,
    offTime: Optional[int] = ...,
) -> int: ...
def freezeAnalogs(deviceName: AnyStr, indexes: List[int]) -> None: ...
def freezeAnalogsAtTime(
    deviceName: AnyStr, absoluteTime: int, intervalTime: int, indexes: List[int]
) -> None: ...
def freezeCounters(deviceName: AnyStr, indexes: List[int]) -> None: ...
def freezeCountersAtTime(
    deviceName: AnyStr, absoluteTime: int, intervalTime: int, indexes: List[int]
) -> None: ...
def selectOperateAnalog(
    deviceName: AnyStr, index: int, value: AnyNum, variation: Optional[int] = ...
) -> int: ...
def selectOperateBinary(
    deviceName: AnyStr,
    indexes: List[int],
    opType: int,
    tcCode: Optional[int] = ...,
    count: Optional[int] = ...,
    onTime: Optional[int] = ...,
    offTime: Optional[int] = ...,
) -> int: ...



from typing import Any, Iterable, List, Mapping, Optional, Sequence

from com.inductiveautomation.ignition.common import Path, QualifiedPath
from com.inductiveautomation.ignition.common.config import Property, PropertyValueSource
from com.inductiveautomation.ignition.common.model.values import QualityCode
from dev.coatl.helper.types import AnyStr
from java.lang import Object

class Result:
    def getDisplayPath(self) -> Path: ...
    def getPath(self) -> QualifiedPath: ...
    def getType(self) -> AnyStr: ...
    def hasChildren(self) -> bool: ...

class BrowseFilter(Object):
    def addExcludeProperty(self, property: Property, value: Object) -> None: ...
    def addNameFilter(self, typeId: AnyStr, *filters: AnyStr) -> BrowseFilter: ...
    def addProperty(self, property: Property, value: Object) -> None: ...
    def checkNameFilters(self, path: Any) -> bool: ...
    def checkProperties(self, toCheck: PropertyValueSource) -> bool: ...
    def getAllowedTypes(self) -> Iterable[AnyStr]: ...
    def getContinuationPoint(self) -> AnyStr: ...
    def getFilterExcludeProperty(
        self, property: Property
    ) -> BrowseFilter.FilterPropertyValue: ...
    def getFilterProperty(
        self, property: Property
    ) -> BrowseFilter.FilterPropertyValue: ...
    def getMaxResults(self) -> int: ...
    def getMeta(self) -> BrowseFilter.Meta: ...
    def getNameFilters(self) -> Iterable[BrowseFilter.NameFilter]: ...
    def getNameFiltersAsMap(self) -> Mapping[AnyStr, BrowseFilter.NameFilter]: ...
    def getOffset(self) -> int: ...
    def isEmptyFilter(self) -> bool: ...
    def isRecursive(self) -> bool: ...
    def setAllowedTypes(self, allowedTypes: Iterable[AnyStr]) -> BrowseFilter: ...
    def setContinuationPoint(self, continuationPoint: AnyStr) -> BrowseFilter: ...
    def setMaxResults(self, maxResults: int) -> BrowseFilter: ...
    def setMeta(self, meta: BrowseFilter.Meta) -> None: ...
    def setNameFilters(
        self, filters: Iterable[BrowseFilter.NameFilter]
    ) -> BrowseFilter: ...
    def setOffset(self, offset: int) -> BrowseFilter: ...
    def setRecursive(self, recursive: bool) -> BrowseFilter: ...

    class FilterPropertyValue(Object):
        property: Property
        value: Object
        def __init__(self, property: Property, value: Object) -> None: ...

    class Meta(Object):
        addFolderOverrides: bool
        def __init__(self, addFolderOverrides: bool) -> None: ...

    class NameFilter(Object):
        def __init__(self, typeId: AnyStr, *filters: AnyStr) -> None: ...
        def getFilters(self) -> Iterable[AnyStr]: ...
        def getTypeId(self) -> AnyStr: ...
        def passes(self, value: AnyStr) -> bool: ...

class Results(Object):
    continuationPoint: Optional[AnyStr]
    resultQuality: QualityCode
    results: Sequence[Any]
    totalAvailableResults: int
    def __init__(self, *args: Any) -> None: ...
    @staticmethod
    def error(result: Results) -> Results: ...
    def getContinuationPoint(self) -> Optional[AnyStr]: ...
    def getResultQuality(self) -> QualityCode: ...
    def getResults(self) -> Sequence[Any]: ...
    def getReturnedSize(self) -> int: ...
    def getTotalAvailableSize(self) -> int: ...
    @staticmethod
    def of(results: List[Any]) -> Results: ...
    def setContinuationPoint(
        self, continuationPoint: Optional[AnyStr] = ...
    ) -> None: ...
    def setResultQuality(self, value: QualityCode) -> None: ...
    def setResults(self, results: List[Any]) -> None: ...
    def setTotalAvailableResults(self, totalAvailableResults: int) -> None: ...



from typing import Any, Callable, Dict, Iterable, List, Optional, Union

from com.inductiveautomation.ignition.common import BasicDataset
from com.inductiveautomation.ignition.common.model import Version
from com.inductiveautomation.ignition.common.script.builtin import (
    DatasetUtilities,
    SystemUtilities,
)
from com.inductiveautomation.ignition.common.util import LoggerEx
from dev.coatl.helper.types import AnyStr
from java.lang import Thread
from java.util import Date, Locale

APPLET_FLAG: int
CLIENT_FLAG: int
DESIGNER_FLAG: int
FULLSCREEN_FLAG: int
MOBILE_FLAG: int
PREVIEW_FLAG: int
SSL_FLAG: int
WEBSTART_FLAG: int
globals: Dict[AnyStr, Any]

def audit(
    action: Optional[AnyStr] = ...,
    actionValue: Optional[AnyStr] = ...,
    auditProfile: AnyStr = ...,
    actor: Optional[AnyStr] = ...,
    actorHost: AnyStr = ...,
    originatingSystem: Optional[List[AnyStr]] = ...,
    eventTimestamp: Optional[Date] = ...,
    originatingContext: int = ...,
    statusCode: int = ...,
) -> None: ...
def beep() -> None: ...
def execute(commands: List[AnyStr]) -> None: ...
def exit(force: bool = ...) -> None: ...
def getAvailableLocales() -> List[AnyStr]: ...
def getAvailableTerms() -> List[AnyStr]: ...
def getClientId() -> unicode: ...
def getConnectTimeout() -> int: ...
def getConnectionMode() -> int: ...
def getEdition() -> AnyStr: ...
def getGatewayAddress() -> unicode: ...
def getGatewayStatus(
    gatewayAddress: AnyStr,
    connectTimeoutMillis: Optional[int] = ...,
    socketTimeoutMillis: Optional[int] = ...,
    bypassCertValidation: bool = ...,
) -> unicode: ...
def getGlobals() -> Dict[AnyStr, Any]: ...
def getInactivitySeconds() -> long: ...
def getLocale() -> AnyStr: ...
def getLogger(name: AnyStr) -> LoggerEx: ...
def getModules() -> BasicDataset: ...
def getProjectName() -> AnyStr: ...
def getProperty(propertyName: AnyStr) -> Optional[unicode]: ...
def getReadTimeout() -> int: ...
def getSessionInfo(
    usernameFilter: Optional[AnyStr] = ..., projectFilter: Optional[AnyStr] = ...
) -> DatasetUtilities.PyDataSet: ...
def getSystemFlags() -> int: ...
def getVersion() -> Version: ...
def invokeAsynchronous(
    function: Callable[..., Any],
    args: Optional[Iterable[Any]] = ...,
    kwargs: Optional[Dict[AnyStr, Any]] = ...,
    description: Optional[AnyStr] = ...,
) -> Thread: ...
def invokeLater(function: Callable[..., Any], delay: int = ...) -> None: ...
def jsonDecode(jsonString: AnyStr) -> Any: ...
def jsonEncode(pyObj: Iterable[Any], indentFactor: int = ...) -> AnyStr: ...
def modifyTranslation(
    term: AnyStr, translation: AnyStr, locale: AnyStr = ...
) -> None: ...
def playSoundClip(wav: Any, volume: float = ..., wait: bool = ...) -> None: ...
def queryAuditLog(
    auditProfileName: Optional[AnyStr] = ...,
    startDate: Optional[Date] = ...,
    endDate: Optional[Date] = ...,
    actorFilter: Optional[AnyStr] = ...,
    actionFilter: Optional[AnyStr] = ...,
    targetFilter: Optional[AnyStr] = ...,
    valueFilter: Optional[AnyStr] = ...,
    systemFilter: Optional[AnyStr] = ...,
    contextFilter: Optional[int] = ...,
) -> BasicDataset: ...
def retarget(
    project: AnyStr,
    addresses: Optional[Union[AnyStr, List[AnyStr]]] = ...,
    params: Optional[Dict[AnyStr, Any]] = ...,
    windows: Optional[List[AnyStr]] = ...,
) -> None: ...
def sendMessage(
    project: AnyStr,
    messageHandler: AnyStr,
    payload: Optional[Dict[AnyStr, Any]] = ...,
    scope: Optional[AnyStr] = ...,
    clientSessionId: Optional[AnyStr] = ...,
    user: Optional[AnyStr] = ...,
    hasRole: Optional[AnyStr] = ...,
    hostName: Optional[AnyStr] = ...,
    remoteServers: Optional[List[AnyStr]] = ...,
) -> List[AnyStr]: ...
def sendRequest(
    project: AnyStr,
    messageHandler: AnyStr,
    payload: Optional[Dict[AnyStr, Any]] = ...,
    hostName: Optional[AnyStr] = ...,
    remoteServer: Optional[AnyStr] = ...,
    timeoutSec: Optional[AnyStr] = ...,
) -> Any: ...
def sendRequestAsync(
    project: AnyStr,
    messageHandler: AnyStr,
    payload: Optional[Dict[AnyStr, Any]] = ...,
    hostName: Optional[AnyStr] = ...,
    remoteServer: Optional[AnyStr] = ...,
    timeoutSec: Optional[int] = ...,
    onSuccess: Optional[Callable[..., Any]] = ...,
    onError: Optional[Callable[..., Any]] = ...,
) -> SystemUtilities.RequestImpl: ...
def setConnectTimeout(connectTimeout: int) -> None: ...
def setConnectionMode(mode: int) -> None: ...
def setLocale(locale: Union[AnyStr, Locale]) -> None: ...
def setLoggingLevel(loggerName: AnyStr, loggerLevel: AnyStr) -> None: ...
def setReadTimeout(readTimeout: int) -> None: ...
def threadDump() -> unicode: ...
def translate(
    term: AnyStr, locale: Optional[AnyStr] = ..., strict: Optional[bool] = ...
) -> AnyStr: ...



from typing import List

from java.lang import Object

class PageFormat(Object):
    LANDSCAPE: int
    PORTRAIT: int
    REVERSE_LANDSCAPE: int
    def clone(self) -> Object: ...
    def getHeight(self) -> float: ...
    def getImageableHeight(self) -> float: ...
    def getImageableWidth(self) -> float: ...
    def getImageableX(self) -> float: ...
    def getImageableY(self) -> float: ...
    def getMatrix(self) -> List[float]: ...
    def getOrientation(self) -> int: ...
    def getPaper(self) -> Paper: ...
    def setOrientation(self, orientation: int) -> None: ...
    def setPaper(self, paper: Paper) -> None: ...

class Paper(Object):
    def clone(self) -> Object: ...
    def getHeight(self) -> float: ...
    def getImageableHeight(self) -> float: ...
    def getImageableWidth(self) -> float: ...
    def getImageableX(self) -> float: ...
    def getImageableY(self) -> float: ...
    def getWidth(self) -> float: ...
    def setImageableArea(
        self, x: float, y: float, width: float, height: float
    ) -> None: ...
    def setSize(self, width: float, height: float) -> None: ...



from typing import Any

from java.lang import Object

class BiConsumer:
    def accept(self, t: Any, u: Any) -> None: ...
    def andThen(self, after: BiConsumer) -> BiConsumer: ...

class BiFunction:
    def andThen(self, after: Function) -> BiFunction: ...
    def apply(self, t: Any, u: Any) -> Any: ...

class BiPredicate:
    def negate(self) -> BiPredicate: ...
    def test(self, t: Any, u: Any) -> bool: ...

class BinaryOperator(BiFunction):
    def apply(self, t: Any, u: Any) -> Any: ...
    @staticmethod
    def maxBy(comparator: Any) -> BinaryOperator: ...
    @staticmethod
    def minBy(comparator: Any) -> BinaryOperator: ...

class Consumer:
    def accept(self, t: Any) -> None: ...
    def andThen(self, after: Consumer) -> Consumer: ...

class Function:
    def andThen(self, after: Function) -> Function: ...
    def apply(self, t: Any) -> Any: ...
    def compose(self, before: Function) -> Function: ...
    @staticmethod
    def identity() -> Function: ...

class Predicate:
    @staticmethod
    def isEqual(targetRef: Object) -> Predicate: ...
    def negate(self) -> Predicate: ...
    def test(self, t: Any) -> bool: ...

class Supplier:
    def get(self) -> Any: ...

class ToDoubleFunction:
    def applyAsDouble(self, value: Any) -> object: ...

class ToIntFunction:
    def applyAsInt(self, value: Any) -> object: ...

class ToLongFunction:
    def applyAsLong(self, value: Any) -> object: ...



from typing import Any, List, Optional

from java.lang import Comparable, Enum, Object, Thread
from java.time.temporal import ChronoUnit

class Delayed(Comparable):
    def compareTo(self, o: Any) -> int: ...
    def getDelay(self, unit: TimeUnit) -> long: ...

class Future:
    def cancel(self, mayInterruptIfRunning: bool) -> bool: ...
    def get(
        self, timeout: Optional[long] = ..., unit: Optional[TimeUnit] = ...
    ) -> Any: ...
    def isCancelled(self) -> bool: ...
    def isDone(self) -> bool: ...

class ScheduledFuture(Delayed, Future):
    def cancel(self, mayInterruptIfRunning: bool) -> bool: ...
    def compareTo(self, o: Any) -> int: ...
    def get(
        self, timeout: Optional[long] = ..., unit: Optional[TimeUnit] = ...
    ) -> Any: ...
    def getDelay(self, unit: TimeUnit) -> long: ...
    def isCancelled(self) -> bool: ...
    def isDone(self) -> bool: ...

class CompletableFuture(Object):
    def __init__(self) -> None: ...

class TimeUnit(Enum):
    DAYS: TimeUnit
    HOURS: TimeUnit
    MICROSECONDS: TimeUnit
    MILLISECONDS: TimeUnit
    MINUTES: TimeUnit
    NANOSECONDS: TimeUnit
    SECONDS: TimeUnit
    def convert(self, *args: Any) -> long: ...
    @staticmethod
    def of(chronoUnit: ChronoUnit) -> TimeUnit: ...
    def sleep(self, timeout: long) -> None: ...
    def timedJoin(self, thread: Thread, timeout: long) -> None: ...
    def timedWait(self, obj: Object, timeout: long) -> None: ...
    def toChronoUnit(self) -> ChronoUnit: ...
    def toDays(self, duration: long) -> long: ...
    def toHours(self, duration: long) -> long: ...
    def toMicros(self, duration: long) -> long: ...
    def toMillis(self, duration: long) -> long: ...
    def toMinutes(self, duration: long) -> long: ...
    def toNanos(self, duration: long) -> long: ...
    def toSeconds(self, duration: long) -> long: ...
    @staticmethod
    def values() -> List[TimeUnit]: ...



from typing import Any, Iterable, List, Optional, Union

from com.inductiveautomation.ignition.common import QualifiedPath
from com.inductiveautomation.ignition.common.config import (
    BasicProperty,
    Property,
    PropertySet,
    PropertyValue,
)
from com.inductiveautomation.ignition.common.user.schedule import ScheduleAdjustment
from dev.coatl.helper.types import AnyStr
from java.lang import Object
from java.util import Date

class User:
    Badge: BasicProperty
    DEFAULT_SCHEDULE_NAME: str
    FirstName: BasicProperty
    Language: BasicProperty
    LastName: BasicProperty
    Notes: BasicProperty
    Password: BasicProperty
    Schedule: BasicProperty
    Username: BasicProperty
    USERNAME_PATTERN: str
    def getContactInfo(self) -> List[ContactInfo]: ...
    def getId(self) -> Any: ...
    def getPath(self) -> QualifiedPath: ...
    def getProfileName(self) -> AnyStr: ...
    def getRoles(self) -> List[AnyStr]: ...
    def getScheduleAdjustments(self) -> List[ScheduleAdjustment]: ...

class AuthenticatedUser(User):
    SecurityZones: Property
    def getContactInfo(self) -> List[ContactInfo]: ...
    def getId(self) -> Any: ...
    def getPath(self) -> QualifiedPath: ...
    def getProfileName(self) -> AnyStr: ...
    def getRoles(self) -> List[AnyStr]: ...
    def getScheduleAdjustments(self) -> List[ScheduleAdjustment]: ...

class ContactInfo(Object):
    contactType: AnyStr
    value: AnyStr
    def __init__(self, *args: Any) -> None: ...
    def getContactType(self) -> AnyStr: ...
    def getValue(self) -> AnyStr: ...
    def setContactType(self, contactType: AnyStr) -> None: ...
    def setValue(self, value: AnyStr) -> None: ...

class BasicUser(User):
    contactInfo: Optional[List[ContactInfo]]
    id: Any
    profileName: AnyStr
    roles: List[AnyStr]
    scheduleAdjustments: List[ScheduleAdjustment]
    def __init__(
        self,
        profileName: AnyStr,
        id_: Any,
        roles: List[AnyStr],
        contactInfo: Optional[List[ContactInfo]] = ...,
    ) -> None: ...
    def getContactInfo(self) -> List[ContactInfo]: ...
    def getId(self) -> Any: ...
    def getPath(self) -> QualifiedPath: ...
    def getProfileName(self) -> AnyStr: ...
    def getRoles(self) -> List[AnyStr]: ...
    def getScheduleAdjustments(self) -> List[ScheduleAdjustment]: ...

class PyUser(User):
    def __init__(self, user: Optional[User] = ...) -> None: ...
    def addContactInfo(self, *args: Any) -> None: ...
    def addRole(self, role: AnyStr) -> None: ...
    def addRoles(self, roles: List[AnyStr]) -> None: ...
    def addScheduleAdjustment(
        self, start: Date, end: Date, available: bool, note: AnyStr
    ) -> None: ...
    def addScheduleAdjustments(
        self, scheduleAdjustments: List[ScheduleAdjustment]
    ) -> None: ...
    def contains(self, prop: Property) -> bool: ...
    def get(self, propertyName: Union[Property, AnyStr]) -> Any: ...
    def getContactInfo(self) -> List[ContactInfo]: ...
    def getCount(self) -> int: ...
    def getId(self) -> Any: ...
    def getOrDefault(self, prop: Property) -> Any: ...
    def getOrElse(self, property: Property, value: Any) -> Any: ...
    def getPath(self) -> QualifiedPath: ...
    def getProfileName(self) -> AnyStr: ...
    def getProperties(self) -> List[Property]: ...
    def getRoles(self) -> List[AnyStr]: ...
    def getScheduleAdjustments(self) -> List[ScheduleAdjustment]: ...
    def getValues(self) -> List[PropertyValue]: ...
    def isExtended(self, prop: Property) -> bool: ...
    def isInherited(self, prop: Property) -> bool: ...
    def iterator(self) -> Iterable[Property]: ...
    def merge(self, other: PropertySet, localOnly: bool) -> None: ...
    def remove(self, prop: Property) -> None: ...
    def removeContactInfo(self, contactType: AnyStr, value: AnyStr) -> None: ...
    def removeRole(self, role: AnyStr) -> None: ...
    def removeScheduleAdjustment(
        self, start: Date, end: Date, available: bool, note: AnyStr
    ) -> None: ...
    def set(self, *args: Any) -> None: ...
    def setContactInfo(self, contactInfo: List[ContactInfo]) -> None: ...
    def setRoles(self, roles: List[AnyStr]) -> None: ...
    def setScheduleAdjustments(
        self, scheduleAdjustments: List[ScheduleAdjustment]
    ) -> None: ...

class UserSourceMeta(Object):
    description: AnyStr
    name: AnyStr
    type: AnyStr
    def __init__(self, name: AnyStr, description: AnyStr, type_: AnyStr) -> None: ...
    def getName(self) -> AnyStr: ...
    def getDescription(self) -> AnyStr: ...
    def getType(self) -> AnyStr: ...



from typing import Any, Dict, List, Optional

from dev.coatl.helper.types import AnyStr

def cancel(deviceName: AnyStr, mapParams: Dict[AnyStr, Any]) -> None: ...
def getControlParams(deviceName: AnyStr) -> List[Dict[AnyStr, Any]]: ...
def listFiles(
    deviceName: AnyStr, remoteFilePath: Optional[AnyStr] = ...
) -> List[AnyStr]: ...
def operate(
    deviceName: AnyStr, mapParams: Dict[AnyStr, Any], controlValue: float
) -> None: ...
def readFile(
    deviceName: AnyStr, remoteFilePath: AnyStr, localFilePath: AnyStr
) -> None: ...
def select(deviceName: AnyStr, mapParams: Dict[AnyStr, Any], value: float) -> None: ...
def writeFile(
    deviceName: AnyStr, localFilePath: AnyStr, remoteFilePath: AnyStr
) -> None: ...



from typing import Any, Iterator, List, Optional

from com.inductiveautomation.ignition.common.gson import JsonObject
from dev.coatl.helper.types import AnyStr
from java.lang import Object
from org.python.core import PyObject

class PyJsonObjectAdapter(Object):
    def __init__(self, obj: JsonObject) -> None: ...
    def __delitem__(self, key: PyObject) -> None: ...
    def __findattr_ex__(self, name: AnyStr) -> PyObject: ...
    def __finditem__(self, key: PyObject) -> PyObject: ...
    def __iter__(self) -> Iterator[Any]: ...
    def __len__(self) -> int: ...
    def __setitem__(self, key: PyObject, value: PyObject) -> None: ...
    def clear(self) -> None: ...
    def get(self, key: PyObject, default: Optional[PyObject] = ...) -> PyObject: ...
    def has_key(self, key: PyObject) -> bool: ...
    def items(self) -> List[PyObject]: ...
    def iteritems(self) -> PyObject: ...
    def iterkeys(self) -> PyObject: ...
    def itervalues(self) -> PyObject: ...
    def keys(self) -> List[PyObject]: ...
    def pop(self, key: PyObject) -> PyObject: ...
    def popitem(self) -> PyObject: ...
    def setdefault(self, key: PyObject, default: PyObject) -> PyObject: ...
    def update(self, *args: PyObject, **kwargs: AnyStr) -> None: ...
    def values(self) -> List[PyObject]: ...



from typing import Any, Iterator, Optional, Union

from dev.coatl.helper.types import AnyStr
from java.lang import Class
from org.python.core import PyInteger, PyList, PyObject, PySequence

class JythonMap:
    def __contains__(self, pyKey: PyObject) -> bool: ...
    def __finditem__(self, key: Union[int, PyObject, AnyStr]) -> PyObject: ...
    def __iter__(self) -> Iterator[Any]: ...
    def __len__(self) -> int: ...
    def get(self, pyKey: PyObject, def_: Optional[PyObject] = ...) -> PyObject: ...
    def has_key(self, pyKey: PyObject) -> bool: ...
    def items(self) -> PyList: ...
    def iteritems(self) -> PyObject: ...
    def iterkeys(self) -> PyObject: ...
    def itervalues(self) -> PyObject: ...
    def keys(self) -> PyList: ...
    def values(self) -> PyList: ...

class JythonSequence:
    def __contains__(self, o: PyObject) -> bool: ...
    def __iter__(self) -> Iterator[Any]: ...
    def __len__(self) -> int: ...
    def __mul__(self, other: PyObject) -> PyObject: ...
    def __rmul__(self, other: PyObject) -> PyObject: ...
    def count(self, element: PyObject) -> PyInteger: ...
    def index(self, element: PyObject) -> int: ...

class MutableJythonMap:
    def __delitem__(self, pyKey: PyObject) -> None: ...
    def __setitem__(self, pyKey: PyObject, pyValue: PyObject) -> None: ...
    def clear(self) -> None: ...
    def pop(self, pyKey: PyObject, def_: Optional[PyObject] = ...) -> PyObject: ...
    def popitem(self) -> PyObject: ...
    def setdefault(
        self, pyKey: PyObject, def_: Optional[PyObject] = ...
    ) -> PyObject: ...
    def update(self, *args: PyObject, **kwargs: AnyStr) -> None: ...

class MutableJythonSequence(JythonSequence):
    def __add__(self, other: PyObject) -> PyObject: ...
    def __contains__(self, o: PyObject) -> bool: ...
    def __imul__(self, other: PyObject) -> PyObject: ...
    def __iter__(self) -> Iterator[Any]: ...
    def __len__(self) -> int: ...
    def __mul__(self, other: PyObject) -> PyObject: ...
    def __rmul__(self, other: PyObject) -> PyObject: ...
    def append(self, element: PyObject) -> None: ...
    def count(self, element: PyObject) -> PyInteger: ...
    def extend(self, sequence: PyObject) -> None: ...
    def index(self, element: PyObject) -> int: ...
    def insert(self, index: int, element: PyObject) -> None: ...
    def pop(self, index: Optional[int] = ...) -> PyObject: ...
    def remove(self, element: PyObject) -> None: ...
    def sort(self, *args: PyObject, **kwargs: AnyStr) -> None: ...

class AbstractJythonMap(JythonMap):
    def __contains__(self, pyKey: PyObject) -> bool: ...
    def __finditem__(self, key: Union[int, PyObject, AnyStr]) -> PyObject: ...
    def __iter__(self) -> Iterator[Any]: ...
    def __len__(self) -> int: ...
    def get(self, pyKey: PyObject, def_: Optional[PyObject] = ...) -> PyObject: ...
    def has_key(self, pyKey: PyObject) -> bool: ...
    def items(self) -> PyList: ...
    def iteritems(self) -> PyObject: ...
    def iterkeys(self) -> PyObject: ...
    def itervalues(self) -> PyObject: ...
    def keys(self) -> PyList: ...
    def values(self) -> PyList: ...

class AbstractJythonSequence(PySequence, JythonSequence):
    def __init__(self, clazz: Class) -> None: ...
    def __add__(self, other: PyObject) -> PyObject: ...
    def __len__(self) -> int: ...
    def __mul__(self, other: PyObject) -> PyObject: ...
    def count(self, element: PyObject) -> PyInteger: ...
    def index(self, element: PyObject) -> int: ...

class AbstractMutableJythonMap(MutableJythonMap):
    def __delitem__(self, pyKey: PyObject) -> None: ...
    def __setitem__(self, pyKey: PyObject, value: PyObject) -> None: ...
    def clear(self) -> None: ...
    def pop(self, pyKey: PyObject, def_: Optional[PyObject] = ...) -> PyObject: ...
    def popitem(self) -> PyObject: ...
    def setdefault(
        self, pyKey: PyObject, def_: Optional[PyObject] = ...
    ) -> PyObject: ...
    def update(self, *args: PyObject, **kwargs: AnyStr) -> None: ...

class AbstractMutableJythonSequence(AbstractJythonSequence, MutableJythonSequence):
    def __add__(self, other: PyObject) -> PyObject: ...
    def append(self, element: PyObject) -> None: ...
    def extend(self, sequence: PyObject) -> None: ...
    def insert(self, index: int, element: PyObject) -> None: ...
    def pop(self, index: Optional[int] = ...) -> PyObject: ...
    def remove(self, element: PyObject) -> None: ...
    def sort(self, *args: PyObject, **kwargs: AnyStr) -> None: ...



from typing import Any

from dev.coatl.helper.types import AnyStr
from java.awt import AWTEvent, Component, Point
from java.lang import Object

class ActionEvent(AWTEvent):
    ACTION_FIRST: int
    ACTION_LAST: int
    ACTION_PERFORMED: int
    ACTION_MASK: int
    CTRL_MASK: int
    META_MASK: int
    SHIFT_MASK: int
    def __init__(self, source: Object, id: int, *args: Any) -> None: ...
    def getActionCommand(self) -> AnyStr: ...
    def getModifiers(self) -> int: ...
    def getWhen(self) -> long: ...

class ComponentEvent(AWTEvent):
    COMPONENT_FIRST: int
    COMPONENT_HIDDEN: int
    COMPONENT_LAST: int
    COMPONENT_MOVED: int
    COMPONENT_RESIZED: int
    COMPONENT_SHOWN: int
    def __init__(self, source: Object, id: int) -> None: ...
    def getComponent(self) -> Component: ...

class InputEvent(ComponentEvent):
    ALT_DOWN_MASK: int
    ALT_GRAPH_DOWN_MASK: int
    ALT_GRAPH_MASL: int
    ALT_MASK: int
    BUTTON1_DOWN_MASK: int
    BUTTOM1_MASK: int
    BUTTON2_DOWN_MASK: int
    BUTTON2_MASK: int
    BUTTON3_DOWN_MASK: int
    BUTTON3_MASK: int
    CTRL_DOWN_MASK: int
    CTRL_MASK: int
    META_DOWN_MASK: int
    META_MASK: int
    SHIFT_DOWN_MASK: int
    SHIFT_MASK: int
    def consume(self) -> None: ...
    @staticmethod
    def getMaskForButton(button: int) -> int: ...
    def getModifiersEx(self) -> int: ...
    @staticmethod
    def getModifiersExText(modifiers: int) -> AnyStr: ...
    def getWhen(self) -> long: ...
    def isAltDown(self) -> bool: ...
    def isAltGraphDown(self) -> bool: ...
    def isConsumed(self) -> bool: ...
    def isControlDown(self) -> bool: ...
    def isMetaDown(self) -> bool: ...
    def isShiftDown(self) -> bool: ...

class MouseEvent(InputEvent):
    BUTTON1: int
    BUTTON2: int
    BUTTON3: int
    MOUSE_CLICKED: int
    MOUSE_DRAGGED: int
    MOUSE_ENTERED: int
    MOUSE_EXITED: int
    MOUSE_FIRST: int
    MOUSE_LAST: int
    MOUSE_MOVED: int
    MOUSE_PRESSED: int
    MOUSE_RELEASED: int
    MOUSE_WHEEL: int
    NOBUTTON: int
    def __init__(self, source: Component, id: int, *args: Any) -> None: ...
    def getButton(self) -> int: ...
    def getClickCount(self) -> int: ...
    def getLocationOnScreen(self) -> Point: ...
    @staticmethod
    def getMouseModifiersText(modifiers: int) -> AnyStr: ...
    def getPoint(self) -> Point: ...
    def getX(self) -> int: ...
    def getXOnScreen(self) -> int: ...
    def getY(self) -> int: ...
    def getYOnScreen(self) -> int: ...
    def isPopupTrigger(self) -> bool: ...
    def translatePoint(self, x: int, y: int) -> None: ...



from typing import Any, Dict, List, Optional, Tuple, Union

from com.inductiveautomation.ignition.common import BasicDataset, Dataset
from com.inductiveautomation.ignition.common.model.values import (
    QualifiedValue,
    QualityCode,
)
from com.inductiveautomation.ignition.common.opc import BrowseElementType
from com.inductiveautomation.ignition.common.script.abc import AbstractJythonSequence
from com.inductiveautomation.ignition.common.script.message import Request
from dev.coatl.helper.types import AnyStr
from java.io import OutputStream, Writer
from java.lang import Class
from java.lang import Exception as JavaException
from java.lang import Object
from java.util import Locale
from org.json import JSONObject
from org.python.core import PyFunction, PyList, PyObject, PySequence
from org.slf4j import Logger

class AbstractOPCUtilities(Object):
    def browseServer(
        self, opcServer: AnyStr, nodeId: AnyStr
    ) -> List[AbstractOPCUtilities.PyOPCTag]: ...
    def getServers(self, *args: PyObject, **kwargs: AnyStr) -> List[AnyStr]: ...
    def getServerState(self, opcServer: AnyStr) -> AnyStr: ...
    def isServerEnabled(self, serverName: AnyStr) -> bool: ...
    def readValue(self, opcServer: AnyStr, itemPath: AnyStr) -> QualifiedValue: ...
    def readValues(
        self, opcServer: AnyStr, itemPaths: List[AnyStr]
    ) -> QualifiedValue: ...
    def setServerEnabled(self, serverName: AnyStr, enabled: bool) -> None: ...
    def writeValue(self, *args: PyObject, **kwargs: AnyStr) -> QualityCode: ...
    def writeValues(self, *args: PyObject, **kwargs: AnyStr) -> List[QualityCode]: ...

    class PyOPCTag(PyObject):
        displayName: AnyStr
        elementType: BrowseElementType
        nodeId: AnyStr
        serverName: AnyStr
        def __init__(
            self,
            serverName: AnyStr,
            nodeId: AnyStr,
            displayName: AnyStr,
            elementType: BrowseElementType,
        ) -> None: ...
        def __findattr_ex__(self, name: AnyStr) -> PyObject: ...
        def getDisplayName(self) -> AnyStr: ...
        def getElementType(self) -> BrowseElementType: ...
        def getNodeId(self) -> AnyStr: ...
        def getServerName(self) -> AnyStr: ...

class DatasetUtilities(Object):
    @staticmethod
    def addColumn(ds: Dataset, *args: Any) -> Dataset: ...
    @staticmethod
    def addRow(ds: Dataset, *args: Any) -> Dataset: ...
    @staticmethod
    def addRows(ds: Dataset, *args: Any) -> Dataset: ...
    @staticmethod
    def appendDataset(ds1: Dataset, ds2: Dataset) -> Dataset: ...
    @staticmethod
    def clearDataset(ds: Dataset) -> Dataset: ...
    @staticmethod
    def dataSetToExcel(headerRow: bool, datasets: List[Object]) -> AnyStr: ...
    @staticmethod
    def dataSetToExcelBytes(
        headerRow: bool,
        objects: List[Object],
        nullsEmpty: bool,
        sheetNames: List[AnyStr],
    ) -> bytearray: ...
    @staticmethod
    def dataSetToExcelStreaming(
        headerRow: bool, objects: List[Object], out: OutputStream, nullsEmpty: bool
    ) -> None: ...
    @staticmethod
    def dataSetToHTML(headerRow: bool, ds: Dataset, title: AnyStr) -> AnyStr: ...
    @staticmethod
    def dataSetToHTMLStreaming(
        headerRow: bool, ds: Dataset, title: AnyStr, fw: Writer
    ) -> None: ...
    @staticmethod
    def deleteRow(ds: Dataset, row: int) -> Dataset: ...
    @staticmethod
    def deleteRows(ds: Dataset, rows: List[int]) -> Dataset: ...
    @staticmethod
    def filterColumns(dataset: Dataset, columns: PySequence) -> Dataset: ...
    @staticmethod
    def formatDates(
        dataset: Dataset, format: AnyStr, locale: Locale = ...
    ) -> Dataset: ...
    @staticmethod
    def fromCSV(csv: AnyStr) -> Dataset: ...
    @staticmethod
    def fromCSVJava(csv: AnyStr) -> Dataset: ...
    @staticmethod
    def getColumnHeaders(ds: Dataset) -> PyList: ...
    @staticmethod
    def insertColumn(ds: Dataset, *args: Any) -> Dataset: ...
    @staticmethod
    def insertRow(ds: Dataset, *args: Any) -> Dataset: ...
    @staticmethod
    def setValue(
        ds: Dataset, row: int, col: Union[int, AnyStr], value: Union[Object, PyObject]
    ) -> Dataset: ...
    @staticmethod
    def sort(
        ds: Dataset,
        keyColumn: Union[int, AnyStr],
        ascending: Optional[bool] = ...,
        naturalOrdering: Optional[bool] = ...,
    ) -> BasicDataset: ...
    @staticmethod
    def toCSV(*args: PyObject, **kwargs: AnyStr) -> AnyStr: ...
    @staticmethod
    def toCSVJava(
        ds: Dataset, showHeaders: bool, forExport: bool, localized: bool = ...
    ) -> AnyStr: ...
    @staticmethod
    def toCSVJavaStreaming(
        ds: Dataset, showHeaders: bool, forExport: bool, sw: Writer, localized: bool
    ) -> None: ...
    @staticmethod
    def toDataSet(*args: Any) -> Dataset: ...
    @staticmethod
    def toExcel(*args: PyObject, **kwargs: AnyStr) -> bytearray: ...
    @staticmethod
    def toJSONObject(data: Dataset) -> JSONObject: ...
    @staticmethod
    def toPyDataSet(dataset: Dataset) -> PyDataSet: ...
    @staticmethod
    def updateRow(ds: Dataset, row: int, changes: Dict[AnyStr, Any]) -> Dataset: ...

    class PyDataSet(Dataset, AbstractJythonSequence):
        def __init__(self, ds: Optional[Dataset] = ...) -> None: ...
        def __add__(self, other: PyObject) -> PyObject: ...
        def getColumnCount(self) -> int: ...
        def getColumnIndex(self, colName: AnyStr) -> int: ...
        def getColumnName(self, col: int) -> AnyStr: ...
        def getColumnNames(self) -> List[AnyStr]: ...
        def getColumnType(self, col: int) -> Class: ...
        def getColumnTypes(self) -> List[Class]: ...
        def getPrimitiveValueAt(self, row: int, col: int) -> float: ...
        def getQualityAt(self, row: int, col: int) -> QualityCode: ...
        def getRowCount(self) -> int: ...
        def getValueAt(self, row: int, col: Union[int, AnyStr]) -> Any: ...
        def setData(self, data: Dataset) -> None: ...

class SProcCall(Object):
    callFinished: bool
    datasource: AnyStr
    params: Dict[SProcCall.SProcArgKey, SProcCall.SProcArg]
    procedureName: AnyStr
    resultset: Dataset
    returnParam: SProcCall.SProcArg
    skipAudit: bool
    txId: AnyStr
    updateCount: int
    def getDataSource(self) -> AnyStr: ...
    def getOutParamValue(self, param: Union[int, AnyStr]) -> Any: ...
    def getProcedureName(self) -> AnyStr: ...
    def getResultSet(self) -> BasicDataset: ...
    def getReturnValue(self) -> Any: ...
    def getTxId(self) -> AnyStr: ...
    def getUpdateCount(self) -> int: ...
    def isSkipAudit(self) -> bool: ...
    def registerInParam(
        self, param: Union[int, AnyStr], typeCode: int, value: Any
    ) -> None: ...
    def registerOutParam(self, param: Union[int, AnyStr], typeCode: int) -> None: ...
    def registerReturnParam(self, typeCode: int) -> None: ...
    def setSkipAudit(self, skipAudit: bool) -> None: ...
    def setTxId(self, txId: AnyStr) -> None: ...

    class SProcArg(Object):
        outParam: bool
        inParam: bool
        paramType: int
        value: Object
        def getParamType(self) -> int: ...
        def getValue(self) -> Any: ...
        def isInParam(self) -> bool: ...
        def isOutParam(self) -> bool: ...
        def setParamType(self, paramType: int) -> None: ...
        def setValue(self, value: Object) -> None: ...

    class SProcArgKey(Object):
        index: int
        name: AnyStr
        def getParamIndex(self) -> int: ...
        def getParamName(self) -> AnyStr: ...
        def isNamedParam(self) -> bool: ...

class SystemUtilities(Object):
    @staticmethod
    def logger(loggerName: AnyStr) -> Logger: ...
    @staticmethod
    def parseTranslateArguments(
        *args: PyObject, **kwargs: AnyStr
    ) -> Tuple[AnyStr, AnyStr, bool]: ...

    class RequestImpl(Object, Request):
        timeout: int
        def __init__(self, timeout: int) -> None: ...
        def cancel(self) -> None: ...
        def checkTimeout(self) -> None: ...
        def finishExceptionally(self, e: JavaException) -> None: ...
        def finishSuccessfully(self, value: Object) -> None: ...
        def get(self) -> Object: ...
        def getError(self) -> JavaException: ...
        def getLongId(self) -> long: ...
        def onError(self, func: PyFunction) -> None: ...
        def onSuccess(self, func: PyFunction) -> None: ...



from typing import Iterable, List

from com.inductiveautomation.ignition.common.util import Timeline
from com.palantir.ptoss.cinch.core import DefaultBindableModel
from dev.coatl.helper.types import AnyStr
from java.lang import Enum
from java.util import Calendar, Date

class AbstractScheduleModel(DefaultBindableModel):
    def __init__(self) -> None: ...
    def getDescription(self) -> AnyStr: ...
    def getName(self) -> AnyStr: ...
    def getScheduleForDay(self, cal: Calendar) -> Timeline: ...
    def getType(self) -> AnyStr: ...
    def isObserveHolidays(self) -> bool: ...
    def setDescription(self, description: AnyStr) -> None: ...
    def setName(self, name: AnyStr) -> None: ...
    def setObserveHolidays(self, observeHolidays: bool) -> None: ...

class BasicScheduleModel(AbstractScheduleModel):
    def __init__(self) -> None: ...
    def getAllDayTime(self) -> AnyStr: ...
    def getFridayTime(self) -> AnyStr: ...
    def getMondayTime(self) -> AnyStr: ...
    def getRepeat(self) -> ScheduleRepeatStyle: ...
    def getRepeatOff(self) -> int: ...
    def getRepeatOn(self) -> int: ...
    def getSaturdayTime(self) -> AnyStr: ...
    def getScheduleForDay(self, cal: Calendar) -> Timeline: ...
    def getStartingAt(self) -> Date: ...
    def getSundayTime(self) -> AnyStr: ...
    def getThursdayTime(self) -> AnyStr: ...
    def getTuesdayTime(self) -> AnyStr: ...
    def getWednesdayTime(self) -> AnyStr: ...
    def getWeekDayTime(self) -> AnyStr: ...
    def isAllDays(self) -> bool: ...
    def isFriday(self) -> bool: ...
    def isMonday(self) -> bool: ...
    def isObserveHolidays(self) -> bool: ...
    def isRepeating(self) -> bool: ...
    def isSaturday(self) -> bool: ...
    def isSunday(self) -> bool: ...
    def isThursday(self) -> bool: ...
    def isTuesday(self) -> bool: ...
    def isUseDays(self) -> bool: ...
    def isWednesday(self) -> bool: ...
    def isWeekDays(self) -> bool: ...
    def set(self, that: BasicScheduleModel) -> None: ...
    def setAllDays(self, allDays: bool) -> None: ...
    def setAllDayTime(self, allDayTime: AnyStr) -> None: ...
    def setFriday(self, friday: bool) -> None: ...
    def setFridayTime(self, fridayTime: AnyStr) -> None: ...
    def setMonday(self, monday: bool) -> None: ...
    def setMondayTime(self, mondayTime: AnyStr) -> None: ...
    def setObserveHolidays(self, observeHolidays: bool) -> None: ...
    def setRepeat(self, repeat: ScheduleRepeatStyle) -> None: ...
    def setRepeatOff(self, repeatOff: int) -> None: ...
    def setRepeatOn(self, repeatOn: int) -> None: ...
    def setSaturday(self, saturday: bool) -> None: ...
    def setSaturdayTime(self, saturdayTime: AnyStr) -> None: ...
    def setStartingAt(self, startingAt: Date) -> None: ...
    def setSunday(self, sunday: bool) -> None: ...
    def setSundayTime(self, sundayTime: AnyStr) -> None: ...
    def setThursday(self, thursday: bool) -> None: ...
    def setThursdayTime(self, thursdayTime: AnyStr) -> None: ...
    def setTuesday(self, tuesday: bool) -> None: ...
    def setTuesdayTime(self, tuesdayTime: AnyStr) -> None: ...
    def setWednesday(self, wednesday: bool) -> None: ...
    def setWednesdayTime(self, wednesdayTime: AnyStr) -> None: ...
    def setWeekDays(self, weekDays: bool) -> None: ...
    def setWeekDayTime(self, weekDayTime: AnyStr) -> None: ...

class CompositeScheduleModel(AbstractScheduleModel):
    def __init__(self, models: List[AbstractScheduleModel]) -> None: ...
    def getModels(self) -> List[AbstractScheduleModel]: ...
    def getScheduleForDay(self, cal: Calendar) -> Timeline: ...
    def isObserveHolidays(self) -> bool: ...
    def setObserveHolidays(self, observeHolidays: bool) -> None: ...

class HolidayModel(DefaultBindableModel):
    date: Date
    name: AnyStr
    repeatAnnually: bool
    def __init__(self, name: AnyStr, date: Date, repeatAnnually: bool) -> None: ...
    def getDate(self) -> Date: ...
    def getName(self) -> AnyStr: ...
    def isRepeatAnnually(self) -> bool: ...
    def set(self, that: HolidayModel) -> None: ...
    def setDate(self, date: Date) -> None: ...
    def setName(self, name: AnyStr) -> None: ...
    def setRepeatAnnually(self, repeatAnnually: bool) -> None: ...

class ScheduleAdjustment(DefaultBindableModel):
    start: Date
    end: Date
    available: bool
    note: AnyStr
    def __init__(
        self, start: Date, end: Date, available: bool, note: AnyStr
    ) -> None: ...
    def contains(self, timestamp: long) -> bool: ...
    def getEnd(self) -> Date: ...
    def getNote(self) -> AnyStr: ...
    def getStart(self) -> Date: ...
    def isAvailable(self) -> bool: ...
    def setAvailable(self, available: bool) -> None: ...
    def setEnd(self, end: Date) -> None: ...
    def setNote(self, note: AnyStr) -> None: ...
    def setStart(self, start: Date) -> None: ...

class ScheduleRepeatStyle(Enum):
    @staticmethod
    def values() -> Iterable[ScheduleRepeatStyle]: ...



from typing import Any, Iterable, List, Mapping, Optional

from com.inductiveautomation.ignition.common.xmlserialization import (
    ClassNameResolver,
    SerializationException,
)
from com.inductiveautomation.ignition.common.xmlserialization.serialization import (
    XMLSerializer,
)
from dev.coatl.helper.types import AnyStr
from java.io import InputStream, Reader
from java.lang import Class, Object

class AttributesMap:
    def getClass(self, name: AnyStr) -> Class: ...
    def getDecoder(self, name: AnyStr) -> Any: ...
    def getInt(self, name: AnyStr) -> int: ...
    def getLength(self) -> int: ...
    def getName(self, index: int) -> AnyStr: ...
    def getSignature(self, name: AnyStr) -> Iterable[Class]: ...
    def getAnyStr(self, name: AnyStr) -> AnyStr: ...
    def getValue(self, name: AnyStr, decoder: Any) -> Any: ...

class DeserializationContext:
    def getClassNameMap(self) -> ClassNameResolver: ...
    def getRootAttributes(self) -> Mapping[AnyStr, AnyStr]: ...
    def getRootObjects(self) -> List[Object]: ...
    def getWarnings(self) -> List[SerializationException]: ...

class DeserializationHandler:
    def clone(self) -> DeserializationHandler: ...
    def endElement(self, context: DeserializationContext) -> None: ...
    def endObject(self, obj: Object) -> None: ...
    def endSubElement(self, name: AnyStr, context: DeserializationContext) -> None: ...
    def getBodyDecoder(self) -> Any: ...
    def getElementName(self) -> AnyStr: ...
    def getObject(self) -> Object: ...
    def getRefId(self) -> int: ...
    def onBody(self, body: Object) -> None: ...
    def setRefId(self, id_: int) -> None: ...
    def startElement(
        self, name: AnyStr, attributes: AttributesMap, context: DeserializationContext
    ) -> None: ...
    def startSubElement(
        self, name: AnyStr, attributes: AttributesMap, context: DeserializationContext
    ) -> None: ...
    def supportsNestedElements(self) -> bool: ...

class XMLDeserializer(Object):
    def __init__(self, resolver: Optional[ClassNameResolver] = ...) -> None: ...
    def addHandler(self, handler: DeserializationHandler) -> None: ...
    def deserialize(self, *args: Any) -> DeserializationContext: ...
    def deserializeBinary(self, *args: Any) -> DeserializationContext: ...
    def deserializeMultiple(
        self, bytes_: bytearray, count: int
    ) -> List[DeserializationContext]: ...
    def deserializeXML(
        self, streamReader: Reader, topAttributesOnly: bool
    ) -> DeserializationContext: ...
    def getClassNameMap(self) -> ClassNameResolver: ...
    def initDefaults(self) -> XMLDeserializer: ...
    def readRootAttributes(self, arg: Any) -> Mapping[AnyStr, AnyStr]: ...
    def transcodeToXML(
        self, binary: InputStream, serializer: XMLSerializer
    ) -> AnyStr: ...



from typing import List

from dev.coatl.helper.types import AnyNum

def geometricMean(values: List[AnyNum]) -> float: ...
def kurtosis(values: List[AnyNum]) -> float: ...
def max(values: List[AnyNum]) -> float: ...
def mean(values: List[AnyNum]) -> float: ...
def meanDifference(values1: List[AnyNum], values2: List[AnyNum]) -> float: ...
def median(values: List[AnyNum]) -> float: ...
def min(values: List[AnyNum]) -> float: ...
def mode(values: List[AnyNum]) -> List[float]: ...
def normalize(values: List[AnyNum]) -> List[float]: ...
def percentile(values: List[AnyNum], percentile: float) -> float: ...
def populationVariance(values: List[AnyNum]) -> float: ...
def product(values: List[AnyNum]) -> float: ...
def skewness(values: List[AnyNum]) -> float: ...
def standardDeviation(values: List[AnyNum]) -> float: ...
def sum(values: List[AnyNum]) -> float: ...
def sumDifference(values1: List[AnyNum], values2: List[AnyNum]) -> float: ...
def sumLog(values: List[AnyNum]) -> float: ...
def sumSquares(values: List[AnyNum]) -> float: ...
def variance(values: List[AnyNum]) -> float: ...



from typing import Any

from dev.coatl.helper.types import AnyStr
from java.lang import Class

class TypeBuilder:
    def getBase(self) -> Class: ...
    def getDict(self, var1: Any) -> Any: ...
    def getDoc(self) -> AnyStr: ...
    def getIsBaseType(self) -> bool: ...
    def getName(self) -> AnyStr: ...
    def getTypeClass(self) -> Class: ...



from typing import Any, List, Optional

from dev.coatl.helper.types import AnyStr

def fileExists(filepath: AnyStr) -> bool: ...
def getTempFile(extension: AnyStr) -> AnyStr: ...
def openFile(
    extension: Optional[AnyStr] = ..., defaultLocation: Optional[AnyStr] = ...
) -> Optional[AnyStr]: ...
def openFiles(
    extension: Optional[AnyStr] = ..., defaultLocation: Optional[AnyStr] = ...
) -> Optional[List[AnyStr]]: ...
def readFileAsBytes(filepath: AnyStr) -> Any: ...
def readFileAsString(filepath: AnyStr, encoding: Optional[AnyStr] = ...) -> AnyStr: ...
def saveFile(
    filename: AnyStr,
    extension: Optional[AnyStr] = ...,
    typeDesc: Optional[AnyStr] = ...,
) -> Optional[AnyStr]: ...
def writeFile(
    filepath: AnyStr, data: Any, append: bool = ..., encoding: AnyStr = ...
) -> None: ...
